# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StepAP214 module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stepap214.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StepAP214
else:
    import _StepAP214

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StepAP214.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StepAP214.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepAP214.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepAP214.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StepAP214.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StepAP214.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StepAP214.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StepAP214.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StepAP214.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StepAP214.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepAP214.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StepAP214.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StepAP214.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepAP214.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepAP214.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepAP214.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StepAP214.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StepAP214:
_StepAP214.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StepAP214.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepBasic
import OCC.Core.TCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepVisual
import OCC.Core.StepShape
import OCC.Core.StepGeom
import OCC.Core.StepRepr
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_StepAP214_AppliedApprovalAssignment_Create() -> "opencascade::handle< StepAP214_AppliedApprovalAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedApprovalAssignment_Create()

def Handle_StepAP214_AppliedApprovalAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedApprovalAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedApprovalAssignment_DownCast(t)

def Handle_StepAP214_AppliedApprovalAssignment_IsNull(t: "opencascade::handle< StepAP214_AppliedApprovalAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedApprovalAssignment_IsNull(t)

def Handle_StepAP214_AppliedDateAndTimeAssignment_Create() -> "opencascade::handle< StepAP214_AppliedDateAndTimeAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedDateAndTimeAssignment_Create()

def Handle_StepAP214_AppliedDateAndTimeAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedDateAndTimeAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedDateAndTimeAssignment_DownCast(t)

def Handle_StepAP214_AppliedDateAndTimeAssignment_IsNull(t: "opencascade::handle< StepAP214_AppliedDateAndTimeAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedDateAndTimeAssignment_IsNull(t)

def Handle_StepAP214_AppliedDateAssignment_Create() -> "opencascade::handle< StepAP214_AppliedDateAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedDateAssignment_Create()

def Handle_StepAP214_AppliedDateAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedDateAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedDateAssignment_DownCast(t)

def Handle_StepAP214_AppliedDateAssignment_IsNull(t: "opencascade::handle< StepAP214_AppliedDateAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedDateAssignment_IsNull(t)

def Handle_StepAP214_AppliedDocumentReference_Create() -> "opencascade::handle< StepAP214_AppliedDocumentReference >":
    return _StepAP214.Handle_StepAP214_AppliedDocumentReference_Create()

def Handle_StepAP214_AppliedDocumentReference_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedDocumentReference >":
    return _StepAP214.Handle_StepAP214_AppliedDocumentReference_DownCast(t)

def Handle_StepAP214_AppliedDocumentReference_IsNull(t: "opencascade::handle< StepAP214_AppliedDocumentReference > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedDocumentReference_IsNull(t)

def Handle_StepAP214_AppliedExternalIdentificationAssignment_Create() -> "opencascade::handle< StepAP214_AppliedExternalIdentificationAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedExternalIdentificationAssignment_Create()

def Handle_StepAP214_AppliedExternalIdentificationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedExternalIdentificationAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedExternalIdentificationAssignment_DownCast(t)

def Handle_StepAP214_AppliedExternalIdentificationAssignment_IsNull(t: "opencascade::handle< StepAP214_AppliedExternalIdentificationAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedExternalIdentificationAssignment_IsNull(t)

def Handle_StepAP214_AppliedGroupAssignment_Create() -> "opencascade::handle< StepAP214_AppliedGroupAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedGroupAssignment_Create()

def Handle_StepAP214_AppliedGroupAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedGroupAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedGroupAssignment_DownCast(t)

def Handle_StepAP214_AppliedGroupAssignment_IsNull(t: "opencascade::handle< StepAP214_AppliedGroupAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedGroupAssignment_IsNull(t)

def Handle_StepAP214_AppliedOrganizationAssignment_Create() -> "opencascade::handle< StepAP214_AppliedOrganizationAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedOrganizationAssignment_Create()

def Handle_StepAP214_AppliedOrganizationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedOrganizationAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedOrganizationAssignment_DownCast(t)

def Handle_StepAP214_AppliedOrganizationAssignment_IsNull(t: "opencascade::handle< StepAP214_AppliedOrganizationAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedOrganizationAssignment_IsNull(t)

def Handle_StepAP214_AppliedPersonAndOrganizationAssignment_Create() -> "opencascade::handle< StepAP214_AppliedPersonAndOrganizationAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedPersonAndOrganizationAssignment_Create()

def Handle_StepAP214_AppliedPersonAndOrganizationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedPersonAndOrganizationAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedPersonAndOrganizationAssignment_DownCast(t)

def Handle_StepAP214_AppliedPersonAndOrganizationAssignment_IsNull(t: "opencascade::handle< StepAP214_AppliedPersonAndOrganizationAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedPersonAndOrganizationAssignment_IsNull(t)

def Handle_StepAP214_AppliedPresentedItem_Create() -> "opencascade::handle< StepAP214_AppliedPresentedItem >":
    return _StepAP214.Handle_StepAP214_AppliedPresentedItem_Create()

def Handle_StepAP214_AppliedPresentedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedPresentedItem >":
    return _StepAP214.Handle_StepAP214_AppliedPresentedItem_DownCast(t)

def Handle_StepAP214_AppliedPresentedItem_IsNull(t: "opencascade::handle< StepAP214_AppliedPresentedItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedPresentedItem_IsNull(t)

def Handle_StepAP214_AppliedSecurityClassificationAssignment_Create() -> "opencascade::handle< StepAP214_AppliedSecurityClassificationAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedSecurityClassificationAssignment_Create()

def Handle_StepAP214_AppliedSecurityClassificationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AppliedSecurityClassificationAssignment >":
    return _StepAP214.Handle_StepAP214_AppliedSecurityClassificationAssignment_DownCast(t)

def Handle_StepAP214_AppliedSecurityClassificationAssignment_IsNull(t: "opencascade::handle< StepAP214_AppliedSecurityClassificationAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AppliedSecurityClassificationAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignActualDateAndTimeAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignActualDateAndTimeAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignActualDateAndTimeAssignment_Create()

def Handle_StepAP214_AutoDesignActualDateAndTimeAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignActualDateAndTimeAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignActualDateAndTimeAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignActualDateAndTimeAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignActualDateAndTimeAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignActualDateAndTimeAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignActualDateAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignActualDateAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignActualDateAssignment_Create()

def Handle_StepAP214_AutoDesignActualDateAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignActualDateAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignActualDateAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignActualDateAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignActualDateAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignActualDateAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignApprovalAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignApprovalAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignApprovalAssignment_Create()

def Handle_StepAP214_AutoDesignApprovalAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignApprovalAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignApprovalAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignApprovalAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignApprovalAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignApprovalAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignDateAndPersonAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignDateAndPersonAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignDateAndPersonAssignment_Create()

def Handle_StepAP214_AutoDesignDateAndPersonAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignDateAndPersonAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignDateAndPersonAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignDateAndPersonAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignDateAndPersonAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignDateAndPersonAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignDocumentReference_Create() -> "opencascade::handle< StepAP214_AutoDesignDocumentReference >":
    return _StepAP214.Handle_StepAP214_AutoDesignDocumentReference_Create()

def Handle_StepAP214_AutoDesignDocumentReference_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignDocumentReference >":
    return _StepAP214.Handle_StepAP214_AutoDesignDocumentReference_DownCast(t)

def Handle_StepAP214_AutoDesignDocumentReference_IsNull(t: "opencascade::handle< StepAP214_AutoDesignDocumentReference > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignDocumentReference_IsNull(t)

def Handle_StepAP214_AutoDesignGroupAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignGroupAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignGroupAssignment_Create()

def Handle_StepAP214_AutoDesignGroupAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignGroupAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignGroupAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignGroupAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignGroupAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignGroupAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignNominalDateAndTimeAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignNominalDateAndTimeAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignNominalDateAndTimeAssignment_Create()

def Handle_StepAP214_AutoDesignNominalDateAndTimeAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignNominalDateAndTimeAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignNominalDateAndTimeAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignNominalDateAndTimeAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignNominalDateAndTimeAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignNominalDateAndTimeAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignNominalDateAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignNominalDateAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignNominalDateAssignment_Create()

def Handle_StepAP214_AutoDesignNominalDateAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignNominalDateAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignNominalDateAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignNominalDateAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignNominalDateAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignNominalDateAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignOrganizationAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignOrganizationAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignOrganizationAssignment_Create()

def Handle_StepAP214_AutoDesignOrganizationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignOrganizationAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignOrganizationAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignOrganizationAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignOrganizationAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignOrganizationAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignPersonAndOrganizationAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignPersonAndOrganizationAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignPersonAndOrganizationAssignment_Create()

def Handle_StepAP214_AutoDesignPersonAndOrganizationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignPersonAndOrganizationAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignPersonAndOrganizationAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignPersonAndOrganizationAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignPersonAndOrganizationAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignPersonAndOrganizationAssignment_IsNull(t)

def Handle_StepAP214_AutoDesignPresentedItem_Create() -> "opencascade::handle< StepAP214_AutoDesignPresentedItem >":
    return _StepAP214.Handle_StepAP214_AutoDesignPresentedItem_Create()

def Handle_StepAP214_AutoDesignPresentedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignPresentedItem >":
    return _StepAP214.Handle_StepAP214_AutoDesignPresentedItem_DownCast(t)

def Handle_StepAP214_AutoDesignPresentedItem_IsNull(t: "opencascade::handle< StepAP214_AutoDesignPresentedItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignPresentedItem_IsNull(t)

def Handle_StepAP214_AutoDesignSecurityClassificationAssignment_Create() -> "opencascade::handle< StepAP214_AutoDesignSecurityClassificationAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignSecurityClassificationAssignment_Create()

def Handle_StepAP214_AutoDesignSecurityClassificationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_AutoDesignSecurityClassificationAssignment >":
    return _StepAP214.Handle_StepAP214_AutoDesignSecurityClassificationAssignment_DownCast(t)

def Handle_StepAP214_AutoDesignSecurityClassificationAssignment_IsNull(t: "opencascade::handle< StepAP214_AutoDesignSecurityClassificationAssignment > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_AutoDesignSecurityClassificationAssignment_IsNull(t)

def Handle_StepAP214_Class_Create() -> "opencascade::handle< StepAP214_Class >":
    return _StepAP214.Handle_StepAP214_Class_Create()

def Handle_StepAP214_Class_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_Class >":
    return _StepAP214.Handle_StepAP214_Class_DownCast(t)

def Handle_StepAP214_Class_IsNull(t: "opencascade::handle< StepAP214_Class > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_Class_IsNull(t)

def Handle_StepAP214_ExternallyDefinedGeneralProperty_Create() -> "opencascade::handle< StepAP214_ExternallyDefinedGeneralProperty >":
    return _StepAP214.Handle_StepAP214_ExternallyDefinedGeneralProperty_Create()

def Handle_StepAP214_ExternallyDefinedGeneralProperty_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_ExternallyDefinedGeneralProperty >":
    return _StepAP214.Handle_StepAP214_ExternallyDefinedGeneralProperty_DownCast(t)

def Handle_StepAP214_ExternallyDefinedGeneralProperty_IsNull(t: "opencascade::handle< StepAP214_ExternallyDefinedGeneralProperty > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_ExternallyDefinedGeneralProperty_IsNull(t)

def Handle_StepAP214_Protocol_Create() -> "opencascade::handle< StepAP214_Protocol >":
    return _StepAP214.Handle_StepAP214_Protocol_Create()

def Handle_StepAP214_Protocol_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_Protocol >":
    return _StepAP214.Handle_StepAP214_Protocol_DownCast(t)

def Handle_StepAP214_Protocol_IsNull(t: "opencascade::handle< StepAP214_Protocol > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_Protocol_IsNull(t)

def Handle_StepAP214_RepItemGroup_Create() -> "opencascade::handle< StepAP214_RepItemGroup >":
    return _StepAP214.Handle_StepAP214_RepItemGroup_Create()

def Handle_StepAP214_RepItemGroup_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_RepItemGroup >":
    return _StepAP214.Handle_StepAP214_RepItemGroup_DownCast(t)

def Handle_StepAP214_RepItemGroup_IsNull(t: "opencascade::handle< StepAP214_RepItemGroup > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_RepItemGroup_IsNull(t)

def Handle_StepAP214_ExternallyDefinedClass_Create() -> "opencascade::handle< StepAP214_ExternallyDefinedClass >":
    return _StepAP214.Handle_StepAP214_ExternallyDefinedClass_Create()

def Handle_StepAP214_ExternallyDefinedClass_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_ExternallyDefinedClass >":
    return _StepAP214.Handle_StepAP214_ExternallyDefinedClass_DownCast(t)

def Handle_StepAP214_ExternallyDefinedClass_IsNull(t: "opencascade::handle< StepAP214_ExternallyDefinedClass > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_ExternallyDefinedClass_IsNull(t)

def Handle_StepAP214_HArray1OfDateItem_Create() -> "opencascade::handle< StepAP214_HArray1OfDateItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfDateItem_Create()

def Handle_StepAP214_HArray1OfDateItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfDateItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfDateItem_DownCast(t)

def Handle_StepAP214_HArray1OfDateItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfDateItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfDateItem_IsNull(t)

def Handle_StepAP214_HArray1OfSecurityClassificationItem_Create() -> "opencascade::handle< StepAP214_HArray1OfSecurityClassificationItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfSecurityClassificationItem_Create()

def Handle_StepAP214_HArray1OfSecurityClassificationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfSecurityClassificationItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfSecurityClassificationItem_DownCast(t)

def Handle_StepAP214_HArray1OfSecurityClassificationItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfSecurityClassificationItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfSecurityClassificationItem_IsNull(t)

def Handle_StepAP214_HArray1OfExternalIdentificationItem_Create() -> "opencascade::handle< StepAP214_HArray1OfExternalIdentificationItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfExternalIdentificationItem_Create()

def Handle_StepAP214_HArray1OfExternalIdentificationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfExternalIdentificationItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfExternalIdentificationItem_DownCast(t)

def Handle_StepAP214_HArray1OfExternalIdentificationItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfExternalIdentificationItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfExternalIdentificationItem_IsNull(t)

def Handle_StepAP214_HArray1OfAutoDesignDatedItem_Create() -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDatedItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignDatedItem_Create()

def Handle_StepAP214_HArray1OfAutoDesignDatedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDatedItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignDatedItem_DownCast(t)

def Handle_StepAP214_HArray1OfAutoDesignDatedItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfAutoDesignDatedItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignDatedItem_IsNull(t)

def Handle_StepAP214_HArray1OfPersonAndOrganizationItem_Create() -> "opencascade::handle< StepAP214_HArray1OfPersonAndOrganizationItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfPersonAndOrganizationItem_Create()

def Handle_StepAP214_HArray1OfPersonAndOrganizationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfPersonAndOrganizationItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfPersonAndOrganizationItem_DownCast(t)

def Handle_StepAP214_HArray1OfPersonAndOrganizationItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfPersonAndOrganizationItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfPersonAndOrganizationItem_IsNull(t)

def Handle_StepAP214_HArray1OfAutoDesignDateAndPersonItem_Create() -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDateAndPersonItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignDateAndPersonItem_Create()

def Handle_StepAP214_HArray1OfAutoDesignDateAndPersonItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDateAndPersonItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignDateAndPersonItem_DownCast(t)

def Handle_StepAP214_HArray1OfAutoDesignDateAndPersonItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfAutoDesignDateAndPersonItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignDateAndPersonItem_IsNull(t)

def Handle_StepAP214_HArray1OfAutoDesignGroupedItem_Create() -> "opencascade::handle< StepAP214_HArray1OfAutoDesignGroupedItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignGroupedItem_Create()

def Handle_StepAP214_HArray1OfAutoDesignGroupedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfAutoDesignGroupedItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignGroupedItem_DownCast(t)

def Handle_StepAP214_HArray1OfAutoDesignGroupedItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfAutoDesignGroupedItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignGroupedItem_IsNull(t)

def Handle_StepAP214_HArray1OfPresentedItemSelect_Create() -> "opencascade::handle< StepAP214_HArray1OfPresentedItemSelect >":
    return _StepAP214.Handle_StepAP214_HArray1OfPresentedItemSelect_Create()

def Handle_StepAP214_HArray1OfPresentedItemSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfPresentedItemSelect >":
    return _StepAP214.Handle_StepAP214_HArray1OfPresentedItemSelect_DownCast(t)

def Handle_StepAP214_HArray1OfPresentedItemSelect_IsNull(t: "opencascade::handle< StepAP214_HArray1OfPresentedItemSelect > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfPresentedItemSelect_IsNull(t)

def Handle_StepAP214_HArray1OfAutoDesignGeneralOrgItem_Create() -> "opencascade::handle< StepAP214_HArray1OfAutoDesignGeneralOrgItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignGeneralOrgItem_Create()

def Handle_StepAP214_HArray1OfAutoDesignGeneralOrgItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfAutoDesignGeneralOrgItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignGeneralOrgItem_DownCast(t)

def Handle_StepAP214_HArray1OfAutoDesignGeneralOrgItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfAutoDesignGeneralOrgItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignGeneralOrgItem_IsNull(t)

def Handle_StepAP214_HArray1OfAutoDesignDateAndTimeItem_Create() -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDateAndTimeItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignDateAndTimeItem_Create()

def Handle_StepAP214_HArray1OfAutoDesignDateAndTimeItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDateAndTimeItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignDateAndTimeItem_DownCast(t)

def Handle_StepAP214_HArray1OfAutoDesignDateAndTimeItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfAutoDesignDateAndTimeItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignDateAndTimeItem_IsNull(t)

def Handle_StepAP214_HArray1OfAutoDesignPresentedItemSelect_Create() -> "opencascade::handle< StepAP214_HArray1OfAutoDesignPresentedItemSelect >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignPresentedItemSelect_Create()

def Handle_StepAP214_HArray1OfAutoDesignPresentedItemSelect_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfAutoDesignPresentedItemSelect >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignPresentedItemSelect_DownCast(t)

def Handle_StepAP214_HArray1OfAutoDesignPresentedItemSelect_IsNull(t: "opencascade::handle< StepAP214_HArray1OfAutoDesignPresentedItemSelect > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignPresentedItemSelect_IsNull(t)

def Handle_StepAP214_HArray1OfAutoDesignReferencingItem_Create() -> "opencascade::handle< StepAP214_HArray1OfAutoDesignReferencingItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignReferencingItem_Create()

def Handle_StepAP214_HArray1OfAutoDesignReferencingItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfAutoDesignReferencingItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignReferencingItem_DownCast(t)

def Handle_StepAP214_HArray1OfAutoDesignReferencingItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfAutoDesignReferencingItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfAutoDesignReferencingItem_IsNull(t)

def Handle_StepAP214_HArray1OfDocumentReferenceItem_Create() -> "opencascade::handle< StepAP214_HArray1OfDocumentReferenceItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfDocumentReferenceItem_Create()

def Handle_StepAP214_HArray1OfDocumentReferenceItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfDocumentReferenceItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfDocumentReferenceItem_DownCast(t)

def Handle_StepAP214_HArray1OfDocumentReferenceItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfDocumentReferenceItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfDocumentReferenceItem_IsNull(t)

def Handle_StepAP214_HArray1OfOrganizationItem_Create() -> "opencascade::handle< StepAP214_HArray1OfOrganizationItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfOrganizationItem_Create()

def Handle_StepAP214_HArray1OfOrganizationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfOrganizationItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfOrganizationItem_DownCast(t)

def Handle_StepAP214_HArray1OfOrganizationItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfOrganizationItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfOrganizationItem_IsNull(t)

def Handle_StepAP214_HArray1OfApprovalItem_Create() -> "opencascade::handle< StepAP214_HArray1OfApprovalItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfApprovalItem_Create()

def Handle_StepAP214_HArray1OfApprovalItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfApprovalItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfApprovalItem_DownCast(t)

def Handle_StepAP214_HArray1OfApprovalItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfApprovalItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfApprovalItem_IsNull(t)

def Handle_StepAP214_HArray1OfGroupItem_Create() -> "opencascade::handle< StepAP214_HArray1OfGroupItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfGroupItem_Create()

def Handle_StepAP214_HArray1OfGroupItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfGroupItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfGroupItem_DownCast(t)

def Handle_StepAP214_HArray1OfGroupItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfGroupItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfGroupItem_IsNull(t)

def Handle_StepAP214_HArray1OfDateAndTimeItem_Create() -> "opencascade::handle< StepAP214_HArray1OfDateAndTimeItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfDateAndTimeItem_Create()

def Handle_StepAP214_HArray1OfDateAndTimeItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP214_HArray1OfDateAndTimeItem >":
    return _StepAP214.Handle_StepAP214_HArray1OfDateAndTimeItem_DownCast(t)

def Handle_StepAP214_HArray1OfDateAndTimeItem_IsNull(t: "opencascade::handle< StepAP214_HArray1OfDateAndTimeItem > const &") -> "bool":
    return _StepAP214.Handle_StepAP214_HArray1OfDateAndTimeItem_IsNull(t)
class StepAP214_Array1OfApprovalItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_ApprovalItem >::iterator":
        return _StepAP214.StepAP214_Array1OfApprovalItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_ApprovalItem >::iterator":
        return _StepAP214.StepAP214_Array1OfApprovalItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_ApprovalItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfApprovalItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_ApprovalItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfApprovalItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfApprovalItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfApprovalItem(*args))

    def Init(self, theValue: "StepAP214_ApprovalItem") -> "void":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfApprovalItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfApprovalItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfApprovalItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfApprovalItem") -> "NCollection_Array1< StepAP214_ApprovalItem > &":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfApprovalItem") -> "NCollection_Array1< StepAP214_ApprovalItem > &":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_ApprovalItem > &":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Set(self, *args)

    def First(self) -> "StepAP214_ApprovalItem const &":
        return _StepAP214.StepAP214_Array1OfApprovalItem_First(self)

    def ChangeFirst(self) -> "StepAP214_ApprovalItem &":
        return _StepAP214.StepAP214_Array1OfApprovalItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_ApprovalItem const &":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Last(self)

    def ChangeLast(self) -> "StepAP214_ApprovalItem &":
        return _StepAP214.StepAP214_Array1OfApprovalItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_ApprovalItem const &":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_ApprovalItem &":
        return _StepAP214.StepAP214_Array1OfApprovalItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_ApprovalItem &":
        return _StepAP214.StepAP214_Array1OfApprovalItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_ApprovalItem") -> "void":
        return _StepAP214.StepAP214_Array1OfApprovalItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfApprovalItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfApprovalItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfApprovalItem in _StepAP214:
_StepAP214.StepAP214_Array1OfApprovalItem_swigregister(StepAP214_Array1OfApprovalItem)

class StepAP214_Array1OfAutoDesignDateAndPersonItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_AutoDesignDateAndPersonItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_AutoDesignDateAndPersonItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_AutoDesignDateAndPersonItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_AutoDesignDateAndPersonItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfAutoDesignDateAndPersonItem(*args))

    def Init(self, theValue: "StepAP214_AutoDesignDateAndPersonItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfAutoDesignDateAndPersonItem") -> "NCollection_Array1< StepAP214_AutoDesignDateAndPersonItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfAutoDesignDateAndPersonItem") -> "NCollection_Array1< StepAP214_AutoDesignDateAndPersonItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_AutoDesignDateAndPersonItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Set(self, *args)

    def First(self) -> "StepAP214_AutoDesignDateAndPersonItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_First(self)

    def ChangeFirst(self) -> "StepAP214_AutoDesignDateAndPersonItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_AutoDesignDateAndPersonItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Last(self)

    def ChangeLast(self) -> "StepAP214_AutoDesignDateAndPersonItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignDateAndPersonItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignDateAndPersonItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_AutoDesignDateAndPersonItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_AutoDesignDateAndPersonItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfAutoDesignDateAndPersonItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfAutoDesignDateAndPersonItem in _StepAP214:
_StepAP214.StepAP214_Array1OfAutoDesignDateAndPersonItem_swigregister(StepAP214_Array1OfAutoDesignDateAndPersonItem)

class StepAP214_Array1OfAutoDesignDateAndTimeItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_AutoDesignDateAndTimeItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_AutoDesignDateAndTimeItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_AutoDesignDateAndTimeItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_AutoDesignDateAndTimeItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfAutoDesignDateAndTimeItem(*args))

    def Init(self, theValue: "StepAP214_AutoDesignDateAndTimeItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfAutoDesignDateAndTimeItem") -> "NCollection_Array1< StepAP214_AutoDesignDateAndTimeItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfAutoDesignDateAndTimeItem") -> "NCollection_Array1< StepAP214_AutoDesignDateAndTimeItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_AutoDesignDateAndTimeItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Set(self, *args)

    def First(self) -> "StepAP214_AutoDesignDateAndTimeItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_First(self)

    def ChangeFirst(self) -> "StepAP214_AutoDesignDateAndTimeItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_AutoDesignDateAndTimeItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Last(self)

    def ChangeLast(self) -> "StepAP214_AutoDesignDateAndTimeItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignDateAndTimeItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignDateAndTimeItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_AutoDesignDateAndTimeItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_AutoDesignDateAndTimeItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfAutoDesignDateAndTimeItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfAutoDesignDateAndTimeItem in _StepAP214:
_StepAP214.StepAP214_Array1OfAutoDesignDateAndTimeItem_swigregister(StepAP214_Array1OfAutoDesignDateAndTimeItem)

class StepAP214_Array1OfAutoDesignDatedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_AutoDesignDatedItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_AutoDesignDatedItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_AutoDesignDatedItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_AutoDesignDatedItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfAutoDesignDatedItem(*args))

    def Init(self, theValue: "StepAP214_AutoDesignDatedItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfAutoDesignDatedItem") -> "NCollection_Array1< StepAP214_AutoDesignDatedItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfAutoDesignDatedItem") -> "NCollection_Array1< StepAP214_AutoDesignDatedItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_AutoDesignDatedItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Set(self, *args)

    def First(self) -> "StepAP214_AutoDesignDatedItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_First(self)

    def ChangeFirst(self) -> "StepAP214_AutoDesignDatedItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_AutoDesignDatedItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Last(self)

    def ChangeLast(self) -> "StepAP214_AutoDesignDatedItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignDatedItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignDatedItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_AutoDesignDatedItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_AutoDesignDatedItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignDatedItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfAutoDesignDatedItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfAutoDesignDatedItem in _StepAP214:
_StepAP214.StepAP214_Array1OfAutoDesignDatedItem_swigregister(StepAP214_Array1OfAutoDesignDatedItem)

class StepAP214_Array1OfAutoDesignGeneralOrgItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_AutoDesignGeneralOrgItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_AutoDesignGeneralOrgItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_AutoDesignGeneralOrgItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_AutoDesignGeneralOrgItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfAutoDesignGeneralOrgItem(*args))

    def Init(self, theValue: "StepAP214_AutoDesignGeneralOrgItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfAutoDesignGeneralOrgItem") -> "NCollection_Array1< StepAP214_AutoDesignGeneralOrgItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfAutoDesignGeneralOrgItem") -> "NCollection_Array1< StepAP214_AutoDesignGeneralOrgItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_AutoDesignGeneralOrgItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Set(self, *args)

    def First(self) -> "StepAP214_AutoDesignGeneralOrgItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_First(self)

    def ChangeFirst(self) -> "StepAP214_AutoDesignGeneralOrgItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_AutoDesignGeneralOrgItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Last(self)

    def ChangeLast(self) -> "StepAP214_AutoDesignGeneralOrgItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignGeneralOrgItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignGeneralOrgItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_AutoDesignGeneralOrgItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_AutoDesignGeneralOrgItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfAutoDesignGeneralOrgItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfAutoDesignGeneralOrgItem in _StepAP214:
_StepAP214.StepAP214_Array1OfAutoDesignGeneralOrgItem_swigregister(StepAP214_Array1OfAutoDesignGeneralOrgItem)

class StepAP214_Array1OfAutoDesignGroupedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_AutoDesignGroupedItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_AutoDesignGroupedItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_AutoDesignGroupedItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_AutoDesignGroupedItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfAutoDesignGroupedItem(*args))

    def Init(self, theValue: "StepAP214_AutoDesignGroupedItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfAutoDesignGroupedItem") -> "NCollection_Array1< StepAP214_AutoDesignGroupedItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfAutoDesignGroupedItem") -> "NCollection_Array1< StepAP214_AutoDesignGroupedItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_AutoDesignGroupedItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Set(self, *args)

    def First(self) -> "StepAP214_AutoDesignGroupedItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_First(self)

    def ChangeFirst(self) -> "StepAP214_AutoDesignGroupedItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_AutoDesignGroupedItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Last(self)

    def ChangeLast(self) -> "StepAP214_AutoDesignGroupedItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignGroupedItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignGroupedItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_AutoDesignGroupedItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_AutoDesignGroupedItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfAutoDesignGroupedItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfAutoDesignGroupedItem in _StepAP214:
_StepAP214.StepAP214_Array1OfAutoDesignGroupedItem_swigregister(StepAP214_Array1OfAutoDesignGroupedItem)

class StepAP214_Array1OfAutoDesignPresentedItemSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_AutoDesignPresentedItemSelect >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_AutoDesignPresentedItemSelect >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_AutoDesignPresentedItemSelect >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_AutoDesignPresentedItemSelect >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_swiginit(self, _StepAP214.new_StepAP214_Array1OfAutoDesignPresentedItemSelect(*args))

    def Init(self, theValue: "StepAP214_AutoDesignPresentedItemSelect") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfAutoDesignPresentedItemSelect") -> "NCollection_Array1< StepAP214_AutoDesignPresentedItemSelect > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfAutoDesignPresentedItemSelect") -> "NCollection_Array1< StepAP214_AutoDesignPresentedItemSelect > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_AutoDesignPresentedItemSelect > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Set(self, *args)

    def First(self) -> "StepAP214_AutoDesignPresentedItemSelect const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_First(self)

    def ChangeFirst(self) -> "StepAP214_AutoDesignPresentedItemSelect &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_ChangeFirst(self)

    def Last(self) -> "StepAP214_AutoDesignPresentedItemSelect const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Last(self)

    def ChangeLast(self) -> "StepAP214_AutoDesignPresentedItemSelect &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignPresentedItemSelect const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignPresentedItemSelect &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_AutoDesignPresentedItemSelect &":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_AutoDesignPresentedItemSelect") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfAutoDesignPresentedItemSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfAutoDesignPresentedItemSelect in _StepAP214:
_StepAP214.StepAP214_Array1OfAutoDesignPresentedItemSelect_swigregister(StepAP214_Array1OfAutoDesignPresentedItemSelect)

class StepAP214_Array1OfAutoDesignReferencingItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_AutoDesignReferencingItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_AutoDesignReferencingItem >::iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_AutoDesignReferencingItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_AutoDesignReferencingItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfAutoDesignReferencingItem(*args))

    def Init(self, theValue: "StepAP214_AutoDesignReferencingItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfAutoDesignReferencingItem") -> "NCollection_Array1< StepAP214_AutoDesignReferencingItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfAutoDesignReferencingItem") -> "NCollection_Array1< StepAP214_AutoDesignReferencingItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_AutoDesignReferencingItem > &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Set(self, *args)

    def First(self) -> "StepAP214_AutoDesignReferencingItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_First(self)

    def ChangeFirst(self) -> "StepAP214_AutoDesignReferencingItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_AutoDesignReferencingItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Last(self)

    def ChangeLast(self) -> "StepAP214_AutoDesignReferencingItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignReferencingItem const &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_AutoDesignReferencingItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_AutoDesignReferencingItem &":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_AutoDesignReferencingItem") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfAutoDesignReferencingItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfAutoDesignReferencingItem in _StepAP214:
_StepAP214.StepAP214_Array1OfAutoDesignReferencingItem_swigregister(StepAP214_Array1OfAutoDesignReferencingItem)

class StepAP214_Array1OfDateAndTimeItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_DateAndTimeItem >::iterator":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_DateAndTimeItem >::iterator":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_DateAndTimeItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_DateAndTimeItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfDateAndTimeItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfDateAndTimeItem(*args))

    def Init(self, theValue: "StepAP214_DateAndTimeItem") -> "void":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfDateAndTimeItem") -> "NCollection_Array1< StepAP214_DateAndTimeItem > &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfDateAndTimeItem") -> "NCollection_Array1< StepAP214_DateAndTimeItem > &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_DateAndTimeItem > &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Set(self, *args)

    def First(self) -> "StepAP214_DateAndTimeItem const &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_First(self)

    def ChangeFirst(self) -> "StepAP214_DateAndTimeItem &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_DateAndTimeItem const &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Last(self)

    def ChangeLast(self) -> "StepAP214_DateAndTimeItem &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_DateAndTimeItem const &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_DateAndTimeItem &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_DateAndTimeItem &":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_DateAndTimeItem") -> "void":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfDateAndTimeItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfDateAndTimeItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfDateAndTimeItem in _StepAP214:
_StepAP214.StepAP214_Array1OfDateAndTimeItem_swigregister(StepAP214_Array1OfDateAndTimeItem)

class StepAP214_Array1OfDateItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_DateItem >::iterator":
        return _StepAP214.StepAP214_Array1OfDateItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_DateItem >::iterator":
        return _StepAP214.StepAP214_Array1OfDateItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_DateItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfDateItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_DateItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfDateItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfDateItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfDateItem(*args))

    def Init(self, theValue: "StepAP214_DateItem") -> "void":
        return _StepAP214.StepAP214_Array1OfDateItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDateItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDateItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfDateItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDateItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDateItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfDateItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfDateItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfDateItem") -> "NCollection_Array1< StepAP214_DateItem > &":
        return _StepAP214.StepAP214_Array1OfDateItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfDateItem") -> "NCollection_Array1< StepAP214_DateItem > &":
        return _StepAP214.StepAP214_Array1OfDateItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_DateItem > &":
        return _StepAP214.StepAP214_Array1OfDateItem_Set(self, *args)

    def First(self) -> "StepAP214_DateItem const &":
        return _StepAP214.StepAP214_Array1OfDateItem_First(self)

    def ChangeFirst(self) -> "StepAP214_DateItem &":
        return _StepAP214.StepAP214_Array1OfDateItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_DateItem const &":
        return _StepAP214.StepAP214_Array1OfDateItem_Last(self)

    def ChangeLast(self) -> "StepAP214_DateItem &":
        return _StepAP214.StepAP214_Array1OfDateItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_DateItem const &":
        return _StepAP214.StepAP214_Array1OfDateItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_DateItem &":
        return _StepAP214.StepAP214_Array1OfDateItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_DateItem &":
        return _StepAP214.StepAP214_Array1OfDateItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_DateItem") -> "void":
        return _StepAP214.StepAP214_Array1OfDateItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfDateItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfDateItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfDateItem in _StepAP214:
_StepAP214.StepAP214_Array1OfDateItem_swigregister(StepAP214_Array1OfDateItem)

class StepAP214_Array1OfDocumentReferenceItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_DocumentReferenceItem >::iterator":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_DocumentReferenceItem >::iterator":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_DocumentReferenceItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_DocumentReferenceItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfDocumentReferenceItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfDocumentReferenceItem(*args))

    def Init(self, theValue: "StepAP214_DocumentReferenceItem") -> "void":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfDocumentReferenceItem") -> "NCollection_Array1< StepAP214_DocumentReferenceItem > &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfDocumentReferenceItem") -> "NCollection_Array1< StepAP214_DocumentReferenceItem > &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_DocumentReferenceItem > &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Set(self, *args)

    def First(self) -> "StepAP214_DocumentReferenceItem const &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_First(self)

    def ChangeFirst(self) -> "StepAP214_DocumentReferenceItem &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_DocumentReferenceItem const &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Last(self)

    def ChangeLast(self) -> "StepAP214_DocumentReferenceItem &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_DocumentReferenceItem const &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_DocumentReferenceItem &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_DocumentReferenceItem &":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_DocumentReferenceItem") -> "void":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfDocumentReferenceItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfDocumentReferenceItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfDocumentReferenceItem in _StepAP214:
_StepAP214.StepAP214_Array1OfDocumentReferenceItem_swigregister(StepAP214_Array1OfDocumentReferenceItem)

class StepAP214_Array1OfExternalIdentificationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_ExternalIdentificationItem >::iterator":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_ExternalIdentificationItem >::iterator":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_ExternalIdentificationItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_ExternalIdentificationItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfExternalIdentificationItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfExternalIdentificationItem(*args))

    def Init(self, theValue: "StepAP214_ExternalIdentificationItem") -> "void":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfExternalIdentificationItem") -> "NCollection_Array1< StepAP214_ExternalIdentificationItem > &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfExternalIdentificationItem") -> "NCollection_Array1< StepAP214_ExternalIdentificationItem > &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_ExternalIdentificationItem > &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Set(self, *args)

    def First(self) -> "StepAP214_ExternalIdentificationItem const &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_First(self)

    def ChangeFirst(self) -> "StepAP214_ExternalIdentificationItem &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_ExternalIdentificationItem const &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Last(self)

    def ChangeLast(self) -> "StepAP214_ExternalIdentificationItem &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_ExternalIdentificationItem const &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_ExternalIdentificationItem &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_ExternalIdentificationItem &":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_ExternalIdentificationItem") -> "void":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfExternalIdentificationItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfExternalIdentificationItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfExternalIdentificationItem in _StepAP214:
_StepAP214.StepAP214_Array1OfExternalIdentificationItem_swigregister(StepAP214_Array1OfExternalIdentificationItem)

class StepAP214_Array1OfGroupItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_GroupItem >::iterator":
        return _StepAP214.StepAP214_Array1OfGroupItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_GroupItem >::iterator":
        return _StepAP214.StepAP214_Array1OfGroupItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_GroupItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfGroupItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_GroupItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfGroupItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfGroupItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfGroupItem(*args))

    def Init(self, theValue: "StepAP214_GroupItem") -> "void":
        return _StepAP214.StepAP214_Array1OfGroupItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfGroupItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfGroupItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfGroupItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfGroupItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfGroupItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfGroupItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfGroupItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfGroupItem") -> "NCollection_Array1< StepAP214_GroupItem > &":
        return _StepAP214.StepAP214_Array1OfGroupItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfGroupItem") -> "NCollection_Array1< StepAP214_GroupItem > &":
        return _StepAP214.StepAP214_Array1OfGroupItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_GroupItem > &":
        return _StepAP214.StepAP214_Array1OfGroupItem_Set(self, *args)

    def First(self) -> "StepAP214_GroupItem const &":
        return _StepAP214.StepAP214_Array1OfGroupItem_First(self)

    def ChangeFirst(self) -> "StepAP214_GroupItem &":
        return _StepAP214.StepAP214_Array1OfGroupItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_GroupItem const &":
        return _StepAP214.StepAP214_Array1OfGroupItem_Last(self)

    def ChangeLast(self) -> "StepAP214_GroupItem &":
        return _StepAP214.StepAP214_Array1OfGroupItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_GroupItem const &":
        return _StepAP214.StepAP214_Array1OfGroupItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_GroupItem &":
        return _StepAP214.StepAP214_Array1OfGroupItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_GroupItem &":
        return _StepAP214.StepAP214_Array1OfGroupItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_GroupItem") -> "void":
        return _StepAP214.StepAP214_Array1OfGroupItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfGroupItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfGroupItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfGroupItem in _StepAP214:
_StepAP214.StepAP214_Array1OfGroupItem_swigregister(StepAP214_Array1OfGroupItem)

class StepAP214_Array1OfOrganizationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_OrganizationItem >::iterator":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_OrganizationItem >::iterator":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_OrganizationItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_OrganizationItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfOrganizationItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfOrganizationItem(*args))

    def Init(self, theValue: "StepAP214_OrganizationItem") -> "void":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfOrganizationItem") -> "NCollection_Array1< StepAP214_OrganizationItem > &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfOrganizationItem") -> "NCollection_Array1< StepAP214_OrganizationItem > &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_OrganizationItem > &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Set(self, *args)

    def First(self) -> "StepAP214_OrganizationItem const &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_First(self)

    def ChangeFirst(self) -> "StepAP214_OrganizationItem &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_OrganizationItem const &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Last(self)

    def ChangeLast(self) -> "StepAP214_OrganizationItem &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_OrganizationItem const &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_OrganizationItem &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_OrganizationItem &":
        return _StepAP214.StepAP214_Array1OfOrganizationItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_OrganizationItem") -> "void":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfOrganizationItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfOrganizationItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfOrganizationItem in _StepAP214:
_StepAP214.StepAP214_Array1OfOrganizationItem_swigregister(StepAP214_Array1OfOrganizationItem)

class StepAP214_Array1OfPersonAndOrganizationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_PersonAndOrganizationItem >::iterator":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_PersonAndOrganizationItem >::iterator":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_PersonAndOrganizationItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_PersonAndOrganizationItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfPersonAndOrganizationItem(*args))

    def Init(self, theValue: "StepAP214_PersonAndOrganizationItem") -> "void":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfPersonAndOrganizationItem") -> "NCollection_Array1< StepAP214_PersonAndOrganizationItem > &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfPersonAndOrganizationItem") -> "NCollection_Array1< StepAP214_PersonAndOrganizationItem > &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_PersonAndOrganizationItem > &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Set(self, *args)

    def First(self) -> "StepAP214_PersonAndOrganizationItem const &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_First(self)

    def ChangeFirst(self) -> "StepAP214_PersonAndOrganizationItem &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_PersonAndOrganizationItem const &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Last(self)

    def ChangeLast(self) -> "StepAP214_PersonAndOrganizationItem &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_PersonAndOrganizationItem const &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_PersonAndOrganizationItem &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_PersonAndOrganizationItem &":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_PersonAndOrganizationItem") -> "void":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfPersonAndOrganizationItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfPersonAndOrganizationItem in _StepAP214:
_StepAP214.StepAP214_Array1OfPersonAndOrganizationItem_swigregister(StepAP214_Array1OfPersonAndOrganizationItem)

class StepAP214_Array1OfPresentedItemSelect(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_PresentedItemSelect >::iterator":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_PresentedItemSelect >::iterator":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_PresentedItemSelect >::const_iterator":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_PresentedItemSelect >::const_iterator":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfPresentedItemSelect_swiginit(self, _StepAP214.new_StepAP214_Array1OfPresentedItemSelect(*args))

    def Init(self, theValue: "StepAP214_PresentedItemSelect") -> "void":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfPresentedItemSelect") -> "NCollection_Array1< StepAP214_PresentedItemSelect > &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfPresentedItemSelect") -> "NCollection_Array1< StepAP214_PresentedItemSelect > &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_PresentedItemSelect > &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Set(self, *args)

    def First(self) -> "StepAP214_PresentedItemSelect const &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_First(self)

    def ChangeFirst(self) -> "StepAP214_PresentedItemSelect &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_ChangeFirst(self)

    def Last(self) -> "StepAP214_PresentedItemSelect const &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Last(self)

    def ChangeLast(self) -> "StepAP214_PresentedItemSelect &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_PresentedItemSelect const &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_PresentedItemSelect &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_PresentedItemSelect &":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_PresentedItemSelect") -> "void":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfPresentedItemSelect_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfPresentedItemSelect

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfPresentedItemSelect in _StepAP214:
_StepAP214.StepAP214_Array1OfPresentedItemSelect_swigregister(StepAP214_Array1OfPresentedItemSelect)

class StepAP214_Array1OfSecurityClassificationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP214_SecurityClassificationItem >::iterator":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP214_SecurityClassificationItem >::iterator":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP214_SecurityClassificationItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP214_SecurityClassificationItem >::const_iterator":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_cend(self)

    def __init__(self, *args):
        _StepAP214.StepAP214_Array1OfSecurityClassificationItem_swiginit(self, _StepAP214.new_StepAP214_Array1OfSecurityClassificationItem(*args))

    def Init(self, theValue: "StepAP214_SecurityClassificationItem") -> "void":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP214_Array1OfSecurityClassificationItem") -> "NCollection_Array1< StepAP214_SecurityClassificationItem > &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP214_Array1OfSecurityClassificationItem") -> "NCollection_Array1< StepAP214_SecurityClassificationItem > &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP214_SecurityClassificationItem > &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Set(self, *args)

    def First(self) -> "StepAP214_SecurityClassificationItem const &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_First(self)

    def ChangeFirst(self) -> "StepAP214_SecurityClassificationItem &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_ChangeFirst(self)

    def Last(self) -> "StepAP214_SecurityClassificationItem const &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Last(self)

    def ChangeLast(self) -> "StepAP214_SecurityClassificationItem &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP214_SecurityClassificationItem const &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP214_SecurityClassificationItem &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP214_SecurityClassificationItem &":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP214_SecurityClassificationItem") -> "void":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP214.StepAP214_Array1OfSecurityClassificationItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP214.delete_StepAP214_Array1OfSecurityClassificationItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP214_Array1OfSecurityClassificationItem in _StepAP214:
_StepAP214.StepAP214_Array1OfSecurityClassificationItem_swigregister(StepAP214_Array1OfSecurityClassificationItem)

class stepap214(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def Protocol(*args) -> "opencascade::handle< StepAP214_Protocol >":
        r"""
        Creates a protocol.

        Returns
        -------
        opencascade::handle<StepAP214_Protocol>

        """
        return _StepAP214.stepap214_Protocol(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _StepAP214.stepap214_swiginit(self, _StepAP214.new_stepap214())
    __swig_destroy__ = _StepAP214.delete_stepap214

# Register stepap214 in _StepAP214:
_StepAP214.stepap214_swigregister(stepap214)

def stepap214_Protocol(*args) -> "opencascade::handle< StepAP214_Protocol >":
    r"""
    Creates a protocol.

    Returns
    -------
    opencascade::handle<StepAP214_Protocol>

    """
    return _StepAP214.stepap214_Protocol(*args)

class StepAP214_AppliedApprovalAssignment(OCC.Core.StepBasic.StepBasic_ApprovalAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a appliedapprovalassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedApprovalAssignment_swiginit(self, _StepAP214.new_StepAP214_AppliedApprovalAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedApproval: StepBasic_Approval
        aItems: StepAP214_HArray1OfApprovalItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedApprovalAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfApprovalItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfApprovalItem>

        """
        return _StepAP214.StepAP214_AppliedApprovalAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_ApprovalItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_ApprovalItem

        """
        return _StepAP214.StepAP214_AppliedApprovalAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AppliedApprovalAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfApprovalItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedApprovalAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedApprovalAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedApprovalAssignment

# Register StepAP214_AppliedApprovalAssignment in _StepAP214:
_StepAP214.StepAP214_AppliedApprovalAssignment_swigregister(StepAP214_AppliedApprovalAssignment)

class StepAP214_AppliedDateAndTimeAssignment(OCC.Core.StepBasic.StepBasic_DateAndTimeAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a applieddateandtimeassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedDateAndTimeAssignment_swiginit(self, _StepAP214.new_StepAP214_AppliedDateAndTimeAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDateAndTime: StepBasic_DateAndTime
        aRole: StepBasic_DateTimeRole
        aItems: StepAP214_HArray1OfDateAndTimeItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedDateAndTimeAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfDateAndTimeItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfDateAndTimeItem>

        """
        return _StepAP214.StepAP214_AppliedDateAndTimeAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_DateAndTimeItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_DateAndTimeItem

        """
        return _StepAP214.StepAP214_AppliedDateAndTimeAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AppliedDateAndTimeAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfDateAndTimeItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedDateAndTimeAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedDateAndTimeAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedDateAndTimeAssignment

# Register StepAP214_AppliedDateAndTimeAssignment in _StepAP214:
_StepAP214.StepAP214_AppliedDateAndTimeAssignment_swigregister(StepAP214_AppliedDateAndTimeAssignment)

class StepAP214_AppliedDateAssignment(OCC.Core.StepBasic.StepBasic_DateAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a applieddateassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedDateAssignment_swiginit(self, _StepAP214.new_StepAP214_AppliedDateAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDate: StepBasic_Date
        aRole: StepBasic_DateRole
        aItems: StepAP214_HArray1OfDateItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedDateAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfDateItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfDateItem>

        """
        return _StepAP214.StepAP214_AppliedDateAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_DateItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_DateItem

        """
        return _StepAP214.StepAP214_AppliedDateAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AppliedDateAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfDateItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedDateAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedDateAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedDateAssignment

# Register StepAP214_AppliedDateAssignment in _StepAP214:
_StepAP214.StepAP214_AppliedDateAssignment_swigregister(StepAP214_AppliedDateAssignment)

class StepAP214_AppliedDocumentReference(OCC.Core.StepBasic.StepBasic_DocumentReference):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedDocumentReference_swiginit(self, _StepAP214.new_StepAP214_AppliedDocumentReference(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDocument: StepBasic_Document
        aSource: TCollection_HAsciiString
        aItems: StepAP214_HArray1OfDocumentReferenceItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedDocumentReference_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfDocumentReferenceItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfDocumentReferenceItem>

        """
        return _StepAP214.StepAP214_AppliedDocumentReference_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_DocumentReferenceItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_DocumentReferenceItem

        """
        return _StepAP214.StepAP214_AppliedDocumentReference_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AppliedDocumentReference_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfDocumentReferenceItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedDocumentReference_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedDocumentReference_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedDocumentReference

# Register StepAP214_AppliedDocumentReference in _StepAP214:
_StepAP214.StepAP214_AppliedDocumentReference_swigregister(StepAP214_AppliedDocumentReference)

class StepAP214_AppliedExternalIdentificationAssignment(OCC.Core.StepBasic.StepBasic_ExternalIdentificationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedExternalIdentificationAssignment_swiginit(self, _StepAP214.new_StepAP214_AppliedExternalIdentificationAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aIdentificationAssignment_AssignedId: TCollection_HAsciiString
        aIdentificationAssignment_Role: StepBasic_IdentificationRole
        aExternalIdentificationAssignment_Source: StepBasic_ExternalSource
        aItems: StepAP214_HArray1OfExternalIdentificationItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedExternalIdentificationAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfExternalIdentificationItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfExternalIdentificationItem>

        """
        return _StepAP214.StepAP214_AppliedExternalIdentificationAssignment_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP214_HArray1OfExternalIdentificationItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedExternalIdentificationAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedExternalIdentificationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedExternalIdentificationAssignment

# Register StepAP214_AppliedExternalIdentificationAssignment in _StepAP214:
_StepAP214.StepAP214_AppliedExternalIdentificationAssignment_swigregister(StepAP214_AppliedExternalIdentificationAssignment)

class StepAP214_AppliedGroupAssignment(OCC.Core.StepBasic.StepBasic_GroupAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedGroupAssignment_swiginit(self, _StepAP214.new_StepAP214_AppliedGroupAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aGroupAssignment_AssignedGroup: StepBasic_Group
        aItems: StepAP214_HArray1OfGroupItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedGroupAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfGroupItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfGroupItem>

        """
        return _StepAP214.StepAP214_AppliedGroupAssignment_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP214_HArray1OfGroupItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedGroupAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedGroupAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedGroupAssignment

# Register StepAP214_AppliedGroupAssignment in _StepAP214:
_StepAP214.StepAP214_AppliedGroupAssignment_swigregister(StepAP214_AppliedGroupAssignment)

class StepAP214_AppliedOrganizationAssignment(OCC.Core.StepBasic.StepBasic_OrganizationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a appliedorganizationassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedOrganizationAssignment_swiginit(self, _StepAP214.new_StepAP214_AppliedOrganizationAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedOrganization: StepBasic_Organization
        aRole: StepBasic_OrganizationRole
        aItems: StepAP214_HArray1OfOrganizationItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedOrganizationAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfOrganizationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfOrganizationItem>

        """
        return _StepAP214.StepAP214_AppliedOrganizationAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_OrganizationItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_OrganizationItem

        """
        return _StepAP214.StepAP214_AppliedOrganizationAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AppliedOrganizationAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfOrganizationItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedOrganizationAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedOrganizationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedOrganizationAssignment

# Register StepAP214_AppliedOrganizationAssignment in _StepAP214:
_StepAP214.StepAP214_AppliedOrganizationAssignment_swigregister(StepAP214_AppliedOrganizationAssignment)

class StepAP214_AppliedPersonAndOrganizationAssignment(OCC.Core.StepBasic.StepBasic_PersonAndOrganizationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesigndateandpersonassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedPersonAndOrganizationAssignment_swiginit(self, _StepAP214.new_StepAP214_AppliedPersonAndOrganizationAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedPersonAndOrganization: StepBasic_PersonAndOrganization
        aRole: StepBasic_PersonAndOrganizationRole
        aItems: StepAP214_HArray1OfPersonAndOrganizationItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedPersonAndOrganizationAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfPersonAndOrganizationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfPersonAndOrganizationItem>

        """
        return _StepAP214.StepAP214_AppliedPersonAndOrganizationAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_PersonAndOrganizationItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_PersonAndOrganizationItem

        """
        return _StepAP214.StepAP214_AppliedPersonAndOrganizationAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AppliedPersonAndOrganizationAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfPersonAndOrganizationItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedPersonAndOrganizationAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedPersonAndOrganizationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedPersonAndOrganizationAssignment

# Register StepAP214_AppliedPersonAndOrganizationAssignment in _StepAP214:
_StepAP214.StepAP214_AppliedPersonAndOrganizationAssignment_swigregister(StepAP214_AppliedPersonAndOrganizationAssignment)

class StepAP214_AppliedPresentedItem(OCC.Core.StepVisual.StepVisual_PresentedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignpresenteditem.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedPresentedItem_swiginit(self, _StepAP214.new_StepAP214_AppliedPresentedItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfPresentedItemSelect

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedPresentedItem_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfPresentedItemSelect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfPresentedItemSelect>

        """
        return _StepAP214.StepAP214_AppliedPresentedItem_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_PresentedItemSelect":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_PresentedItemSelect

        """
        return _StepAP214.StepAP214_AppliedPresentedItem_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AppliedPresentedItem_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfPresentedItemSelect

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedPresentedItem_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedPresentedItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedPresentedItem

# Register StepAP214_AppliedPresentedItem in _StepAP214:
_StepAP214.StepAP214_AppliedPresentedItem_swigregister(StepAP214_AppliedPresentedItem)

class StepAP214_AppliedSecurityClassificationAssignment(OCC.Core.StepBasic.StepBasic_SecurityClassificationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a appliedsecurityclassificationassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AppliedSecurityClassificationAssignment_swiginit(self, _StepAP214.new_StepAP214_AppliedSecurityClassificationAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedSecurityClassification: StepBasic_SecurityClassification
        aItems: StepAP214_HArray1OfSecurityClassificationItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedSecurityClassificationAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfSecurityClassificationItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfSecurityClassificationItem>

        """
        return _StepAP214.StepAP214_AppliedSecurityClassificationAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_SecurityClassificationItem const &":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_SecurityClassificationItem

        """
        return _StepAP214.StepAP214_AppliedSecurityClassificationAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AppliedSecurityClassificationAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfSecurityClassificationItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AppliedSecurityClassificationAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AppliedSecurityClassificationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AppliedSecurityClassificationAssignment

# Register StepAP214_AppliedSecurityClassificationAssignment in _StepAP214:
_StepAP214.StepAP214_AppliedSecurityClassificationAssignment_swigregister(StepAP214_AppliedSecurityClassificationAssignment)

class StepAP214_ApprovalItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a approvalitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_ApprovalItem_swiginit(self, _StepAP214.new_StepAP214_ApprovalItem(*args))

    def AssemblyComponentUsageSubstitute(self, *args) -> "opencascade::handle< StepRepr_AssemblyComponentUsageSubstitute >":
        r"""
        Returns value as a assemblycomponentusagesubstitute (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_AssemblyComponentUsageSubstitute>

        """
        return _StepAP214.StepAP214_ApprovalItem_AssemblyComponentUsageSubstitute(self, *args)

    def ConfigurationItem(self, *args) -> "opencascade::handle< StepRepr_ConfigurationItem >":
        r"""
        Returns value as a configurationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ConfigurationItem>

        """
        return _StepAP214.StepAP214_ApprovalItem_ConfigurationItem(self, *args)

    def Date(self, *args) -> "opencascade::handle< StepBasic_Date >":
        r"""
        Returns value as a date (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Date>

        """
        return _StepAP214.StepAP214_ApprovalItem_Date(self, *args)

    def Document(self, *args) -> "opencascade::handle< StepBasic_Document >":
        r"""
        Returns value as a document (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Document>

        """
        return _StepAP214.StepAP214_ApprovalItem_Document(self, *args)

    def DocumentFile(self, *args) -> "opencascade::handle< StepBasic_DocumentFile >":
        r"""
        Returns value as a documentfile (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_DocumentFile>

        """
        return _StepAP214.StepAP214_ApprovalItem_DocumentFile(self, *args)

    def Effectivity(self, *args) -> "opencascade::handle< StepBasic_Effectivity >":
        r"""
        Returns value as a effectivity (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Effectivity>

        """
        return _StepAP214.StepAP214_ApprovalItem_Effectivity(self, *args)

    def Group(self, *args) -> "opencascade::handle< StepBasic_Group >":
        r"""
        Returns value as a group (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Group>

        """
        return _StepAP214.StepAP214_ApprovalItem_Group(self, *args)

    def GroupRelationship(self, *args) -> "opencascade::handle< StepBasic_GroupRelationship >":
        r"""
        Returns value as a grouprelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_GroupRelationship>

        """
        return _StepAP214.StepAP214_ApprovalItem_GroupRelationship(self, *args)

    def MaterialDesignation(self, *args) -> "opencascade::handle< StepRepr_MaterialDesignation >":
        r"""
        Returns value as a materialdesignation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_MaterialDesignation>

        """
        return _StepAP214.StepAP214_ApprovalItem_MaterialDesignation(self, *args)

    def MechanicalDesignGeometricPresentationRepresentation(self, *args) -> "opencascade::handle< StepVisual_MechanicalDesignGeometricPresentationRepresentation >":
        r"""
        Returns value as a mechanicaldesigngeometricpresentationrepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_MechanicalDesignGeometricPresentationRepresentation>

        """
        return _StepAP214.StepAP214_ApprovalItem_MechanicalDesignGeometricPresentationRepresentation(self, *args)

    def PresentationArea(self, *args) -> "opencascade::handle< StepVisual_PresentationArea >":
        r"""
        Returns value as a presentationarea (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_PresentationArea>

        """
        return _StepAP214.StepAP214_ApprovalItem_PresentationArea(self, *args)

    def Product(self, *args) -> "opencascade::handle< StepBasic_Product >":
        r"""
        Returns value as a product (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Product>

        """
        return _StepAP214.StepAP214_ApprovalItem_Product(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as a productdefinition (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP214.StepAP214_ApprovalItem_ProductDefinition(self, *args)

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as a productdefinitionformation (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP214.StepAP214_ApprovalItem_ProductDefinitionFormation(self, *args)

    def ProductDefinitionFormationRelationship(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormationRelationship >":
        r"""
        Returns value as a productdefinitionformationrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormationRelationship>

        """
        return _StepAP214.StepAP214_ApprovalItem_ProductDefinitionFormationRelationship(self, *args)

    def ProductDefinitionRelationship(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
        r"""
        Returns value as aproductdefinitionrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionRelationship>

        """
        return _StepAP214.StepAP214_ApprovalItem_ProductDefinitionRelationship(self, *args)

    def PropertyDefinition(self, *args) -> "opencascade::handle< StepRepr_PropertyDefinition >":
        r"""
        Returns value as a propertydefinition (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_PropertyDefinition>

        """
        return _StepAP214.StepAP214_ApprovalItem_PropertyDefinition(self, *args)

    def Representation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        Returns value as a representation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepAP214.StepAP214_ApprovalItem_Representation(self, *args)

    def SecurityClassification(self, *args) -> "opencascade::handle< StepBasic_SecurityClassification >":
        r"""
        Returns value as a securityclassification (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_SecurityClassification>

        """
        return _StepAP214.StepAP214_ApprovalItem_SecurityClassification(self, *args)

    def ShapeAspectRelationship(self, *args) -> "opencascade::handle< StepRepr_ShapeAspectRelationship >":
        r"""
        Returns value as a shapeaspectrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspectRelationship>

        """
        return _StepAP214.StepAP214_ApprovalItem_ShapeAspectRelationship(self, *args)

    def ShapeRepresentation(self, *args) -> "opencascade::handle< StepShape_ShapeRepresentation >":
        r"""
        Returns value as a shaperepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_ShapeRepresentation>

        """
        return _StepAP214.StepAP214_ApprovalItem_ShapeRepresentation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_ApprovalItem

# Register StepAP214_ApprovalItem in _StepAP214:
_StepAP214.StepAP214_ApprovalItem_swigregister(StepAP214_ApprovalItem)

class StepAP214_AutoDesignActualDateAndTimeAssignment(OCC.Core.StepBasic.StepBasic_DateAndTimeAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignactualdateandtimeassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignActualDateAndTimeAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignActualDateAndTimeAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDateAndTime: StepBasic_DateAndTime
        aRole: StepBasic_DateTimeRole
        aItems: StepAP214_HArray1OfAutoDesignDateAndTimeItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAndTimeAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDateAndTimeItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignDateAndTimeItem>

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAndTimeAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignDateAndTimeItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignDateAndTimeItem

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAndTimeAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAndTimeAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignDateAndTimeItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAndTimeAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignActualDateAndTimeAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignActualDateAndTimeAssignment

# Register StepAP214_AutoDesignActualDateAndTimeAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignActualDateAndTimeAssignment_swigregister(StepAP214_AutoDesignActualDateAndTimeAssignment)

class StepAP214_AutoDesignActualDateAssignment(OCC.Core.StepBasic.StepBasic_DateAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignactualdateassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignActualDateAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignActualDateAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDate: StepBasic_Date
        aRole: StepBasic_DateRole
        aItems: StepAP214_HArray1OfAutoDesignDatedItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDatedItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignDatedItem>

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignDatedItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignDatedItem

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignDatedItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignActualDateAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignActualDateAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignActualDateAssignment

# Register StepAP214_AutoDesignActualDateAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignActualDateAssignment_swigregister(StepAP214_AutoDesignActualDateAssignment)

class StepAP214_AutoDesignApprovalAssignment(OCC.Core.StepBasic.StepBasic_ApprovalAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignapprovalassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignApprovalAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignApprovalAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedApproval: StepBasic_Approval
        aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignApprovalAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignGeneralOrgItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignGeneralOrgItem>

        """
        return _StepAP214.StepAP214_AutoDesignApprovalAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignGeneralOrgItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignGeneralOrgItem

        """
        return _StepAP214.StepAP214_AutoDesignApprovalAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignApprovalAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignApprovalAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignApprovalAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignApprovalAssignment

# Register StepAP214_AutoDesignApprovalAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignApprovalAssignment_swigregister(StepAP214_AutoDesignApprovalAssignment)

class StepAP214_AutoDesignDateAndPersonAssignment(OCC.Core.StepBasic.StepBasic_PersonAndOrganizationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesigndateandpersonassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignDateAndPersonAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignDateAndPersonAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedPersonAndOrganization: StepBasic_PersonAndOrganization
        aRole: StepBasic_PersonAndOrganizationRole
        aItems: StepAP214_HArray1OfAutoDesignDateAndPersonItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDateAndPersonItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignDateAndPersonItem>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignDateAndPersonItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignDateAndPersonItem

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignDateAndPersonItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignDateAndPersonAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignDateAndPersonAssignment

# Register StepAP214_AutoDesignDateAndPersonAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignDateAndPersonAssignment_swigregister(StepAP214_AutoDesignDateAndPersonAssignment)

class StepAP214_AutoDesignDateAndPersonItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesigndateandpersonitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignDateAndPersonItem_swiginit(self, _StepAP214.new_StepAP214_AutoDesignDateAndPersonItem(*args))

    def AutoDesignDocumentReference(self, *args) -> "opencascade::handle< StepAP214_AutoDesignDocumentReference >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_AutoDesignDocumentReference>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonItem_AutoDesignDocumentReference(self, *args)

    def AutoDesignOrganizationAssignment(self, *args) -> "opencascade::handle< StepAP214_AutoDesignOrganizationAssignment >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_AutoDesignOrganizationAssignment>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonItem_AutoDesignOrganizationAssignment(self, *args)

    def ExternallyDefinedRepresentation(self, *args) -> "opencascade::handle< StepRepr_ExternallyDefinedRepresentation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_ExternallyDefinedRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonItem_ExternallyDefinedRepresentation(self, *args)

    def Product(self, *args) -> "opencascade::handle< StepBasic_Product >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Product>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonItem_Product(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonItem_ProductDefinition(self, *args)

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonItem_ProductDefinitionFormation(self, *args)

    def ProductDefinitionRelationship(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionRelationship>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonItem_ProductDefinitionRelationship(self, *args)

    def ProductDefinitionWithAssociatedDocuments(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionWithAssociatedDocuments >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionWithAssociatedDocuments>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonItem_ProductDefinitionWithAssociatedDocuments(self, *args)

    def Representation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndPersonItem_Representation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignDateAndPersonItem

# Register StepAP214_AutoDesignDateAndPersonItem in _StepAP214:
_StepAP214.StepAP214_AutoDesignDateAndPersonItem_swigregister(StepAP214_AutoDesignDateAndPersonItem)

class StepAP214_AutoDesignDateAndTimeItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesigndateandtimeitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignDateAndTimeItem_swiginit(self, _StepAP214.new_StepAP214_AutoDesignDateAndTimeItem(*args))

    def ApprovalPersonOrganization(self, *args) -> "opencascade::handle< StepBasic_ApprovalPersonOrganization >":
        r"""
        Returns value as a approvalpersonorganization (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalPersonOrganization>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndTimeItem_ApprovalPersonOrganization(self, *args)

    def AutoDesignDateAndPersonAssignment(self, *args) -> "opencascade::handle< StepAP214_AutoDesignDateAndPersonAssignment >":
        r"""
        Returns value as a autodesigndateandpersonassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AutoDesignDateAndPersonAssignment>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndTimeItem_AutoDesignDateAndPersonAssignment(self, *args)

    def ProductDefinitionEffectivity(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionEffectivity >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionEffectivity>

        """
        return _StepAP214.StepAP214_AutoDesignDateAndTimeItem_ProductDefinitionEffectivity(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignDateAndTimeItem

# Register StepAP214_AutoDesignDateAndTimeItem in _StepAP214:
_StepAP214.StepAP214_AutoDesignDateAndTimeItem_swigregister(StepAP214_AutoDesignDateAndTimeItem)

class StepAP214_AutoDesignDatedItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesigndateditem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignDatedItem_swiginit(self, _StepAP214.new_StepAP214_AutoDesignDatedItem(*args))

    def ApprovalPersonOrganization(self, *args) -> "opencascade::handle< StepBasic_ApprovalPersonOrganization >":
        r"""
        Returns value as a approvalpersonorganization (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalPersonOrganization>

        """
        return _StepAP214.StepAP214_AutoDesignDatedItem_ApprovalPersonOrganization(self, *args)

    def AutoDesignDateAndPersonAssignment(self, *args) -> "opencascade::handle< StepAP214_AutoDesignDateAndPersonAssignment >":
        r"""
        Returns value as a autodesigndateandpersonassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AutoDesignDateAndPersonAssignment>

        """
        return _StepAP214.StepAP214_AutoDesignDatedItem_AutoDesignDateAndPersonAssignment(self, *args)

    def ProductDefinitionEffectivity(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionEffectivity >":
        r"""
        Returns value as a productdefinitioneffectivity.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionEffectivity>

        """
        return _StepAP214.StepAP214_AutoDesignDatedItem_ProductDefinitionEffectivity(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignDatedItem

# Register StepAP214_AutoDesignDatedItem in _StepAP214:
_StepAP214.StepAP214_AutoDesignDatedItem_swigregister(StepAP214_AutoDesignDatedItem)

class StepAP214_AutoDesignDocumentReference(OCC.Core.StepBasic.StepBasic_DocumentReference):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignDocumentReference_swiginit(self, _StepAP214.new_StepAP214_AutoDesignDocumentReference(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDocument: StepBasic_Document
        aSource: TCollection_HAsciiString
        aItems: StepAP214_HArray1OfAutoDesignReferencingItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignDocumentReference_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignReferencingItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignReferencingItem>

        """
        return _StepAP214.StepAP214_AutoDesignDocumentReference_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignReferencingItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignReferencingItem

        """
        return _StepAP214.StepAP214_AutoDesignDocumentReference_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignDocumentReference_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignReferencingItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignDocumentReference_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignDocumentReference_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignDocumentReference

# Register StepAP214_AutoDesignDocumentReference in _StepAP214:
_StepAP214.StepAP214_AutoDesignDocumentReference_swigregister(StepAP214_AutoDesignDocumentReference)

class StepAP214_AutoDesignGeneralOrgItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesigngeneralorgitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignGeneralOrgItem_swiginit(self, _StepAP214.new_StepAP214_AutoDesignGeneralOrgItem(*args))

    def AutoDesignDocumentReference(self, *args) -> "opencascade::handle< StepAP214_AutoDesignDocumentReference >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_AutoDesignDocumentReference>

        """
        return _StepAP214.StepAP214_AutoDesignGeneralOrgItem_AutoDesignDocumentReference(self, *args)

    def ExternallyDefinedRepresentation(self, *args) -> "opencascade::handle< StepRepr_ExternallyDefinedRepresentation >":
        r"""
        Returns value as a representation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ExternallyDefinedRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignGeneralOrgItem_ExternallyDefinedRepresentation(self, *args)

    def Product(self, *args) -> "opencascade::handle< StepBasic_Product >":
        r"""
        Returns value as a product (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Product>

        """
        return _StepAP214.StepAP214_AutoDesignGeneralOrgItem_Product(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as a productdefinition (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP214.StepAP214_AutoDesignGeneralOrgItem_ProductDefinition(self, *args)

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as a productdefinitionformation (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP214.StepAP214_AutoDesignGeneralOrgItem_ProductDefinitionFormation(self, *args)

    def ProductDefinitionRelationship(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
        r"""
        Returns value as a productdefinitionrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionRelationship>

        """
        return _StepAP214.StepAP214_AutoDesignGeneralOrgItem_ProductDefinitionRelationship(self, *args)

    def ProductDefinitionWithAssociatedDocuments(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionWithAssociatedDocuments >":
        r"""
        Returns value as a productdefinitionwithassociateddocuments (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionWithAssociatedDocuments>

        """
        return _StepAP214.StepAP214_AutoDesignGeneralOrgItem_ProductDefinitionWithAssociatedDocuments(self, *args)

    def Representation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        Returns value as a representation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepAP214.StepAP214_AutoDesignGeneralOrgItem_Representation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignGeneralOrgItem

# Register StepAP214_AutoDesignGeneralOrgItem in _StepAP214:
_StepAP214.StepAP214_AutoDesignGeneralOrgItem_swigregister(StepAP214_AutoDesignGeneralOrgItem)

class StepAP214_AutoDesignGroupAssignment(OCC.Core.StepBasic.StepBasic_GroupAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesigngroupassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignGroupAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignGroupAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedGroup: StepBasic_Group
        aItems: StepAP214_HArray1OfAutoDesignGroupedItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignGroupAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignGroupedItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignGroupedItem>

        """
        return _StepAP214.StepAP214_AutoDesignGroupAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignGroupedItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignGroupedItem

        """
        return _StepAP214.StepAP214_AutoDesignGroupAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignGroupAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignGroupedItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignGroupAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignGroupAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignGroupAssignment

# Register StepAP214_AutoDesignGroupAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignGroupAssignment_swigregister(StepAP214_AutoDesignGroupAssignment)

class StepAP214_AutoDesignGroupedItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesigngroupeditem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignGroupedItem_swiginit(self, _StepAP214.new_StepAP214_AutoDesignGroupedItem(*args))

    def AdvancedBrepShapeRepresentation(self, *args) -> "opencascade::handle< StepShape_AdvancedBrepShapeRepresentation >":
        r"""
        Returns value as a advancedbrepshaperepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_AdvancedBrepShapeRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_AdvancedBrepShapeRepresentation(self, *args)

    def CsgShapeRepresentation(self, *args) -> "opencascade::handle< StepShape_CsgShapeRepresentation >":
        r"""
        Returns value as a csgshaperepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_CsgShapeRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_CsgShapeRepresentation(self, *args)

    def FacetedBrepShapeRepresentation(self, *args) -> "opencascade::handle< StepShape_FacetedBrepShapeRepresentation >":
        r"""
        Returns value as a facetedbrepshaperepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_FacetedBrepShapeRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_FacetedBrepShapeRepresentation(self, *args)

    def GeometricallyBoundedSurfaceShapeRepresentation(self, *args) -> "opencascade::handle< StepShape_GeometricallyBoundedSurfaceShapeRepresentation >":
        r"""
        Returns value as a geometricallyboundedsurfaceshaperepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_GeometricallyBoundedSurfaceShapeRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_GeometricallyBoundedSurfaceShapeRepresentation(self, *args)

    def GeometricallyBoundedWireframeShapeRepresentation(self, *args) -> "opencascade::handle< StepShape_GeometricallyBoundedWireframeShapeRepresentation >":
        r"""
        Returns value as a geometricallyboundedwireframeshaperepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_GeometricallyBoundedWireframeShapeRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_GeometricallyBoundedWireframeShapeRepresentation(self, *args)

    def ManifoldSurfaceShapeRepresentation(self, *args) -> "opencascade::handle< StepShape_ManifoldSurfaceShapeRepresentation >":
        r"""
        Returns value as a manifoldsurfaceshaperepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_ManifoldSurfaceShapeRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_ManifoldSurfaceShapeRepresentation(self, *args)

    def Representation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        Returns value as a representation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_Representation(self, *args)

    def RepresentationItem(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        Returns value as a representationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_RepresentationItem(self, *args)

    def ShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns value as a shapeaspect (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_ShapeAspect(self, *args)

    def ShapeRepresentation(self, *args) -> "opencascade::handle< StepShape_ShapeRepresentation >":
        r"""
        Returns value as a shaperepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_ShapeRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_ShapeRepresentation(self, *args)

    def TemplateInstance(self, *args) -> "opencascade::handle< StepVisual_TemplateInstance >":
        r"""
        Returns value as a templateinstance (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_TemplateInstance>

        """
        return _StepAP214.StepAP214_AutoDesignGroupedItem_TemplateInstance(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignGroupedItem

# Register StepAP214_AutoDesignGroupedItem in _StepAP214:
_StepAP214.StepAP214_AutoDesignGroupedItem_swigregister(StepAP214_AutoDesignGroupedItem)

class StepAP214_AutoDesignNominalDateAndTimeAssignment(OCC.Core.StepBasic.StepBasic_DateAndTimeAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignnominaldateandtimeassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignNominalDateAndTimeAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignNominalDateAndTimeAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDateAndTime: StepBasic_DateAndTime
        aRole: StepBasic_DateTimeRole
        aItems: StepAP214_HArray1OfAutoDesignDateAndTimeItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAndTimeAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDateAndTimeItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignDateAndTimeItem>

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAndTimeAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignDateAndTimeItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignDateAndTimeItem

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAndTimeAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAndTimeAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignDateAndTimeItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAndTimeAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignNominalDateAndTimeAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignNominalDateAndTimeAssignment

# Register StepAP214_AutoDesignNominalDateAndTimeAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignNominalDateAndTimeAssignment_swigregister(StepAP214_AutoDesignNominalDateAndTimeAssignment)

class StepAP214_AutoDesignNominalDateAssignment(OCC.Core.StepBasic.StepBasic_DateAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignnominaldateassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignNominalDateAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignNominalDateAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedDate: StepBasic_Date
        aRole: StepBasic_DateRole
        aItems: StepAP214_HArray1OfAutoDesignDatedItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignDatedItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignDatedItem>

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignDatedItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignDatedItem

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignDatedItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignNominalDateAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignNominalDateAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignNominalDateAssignment

# Register StepAP214_AutoDesignNominalDateAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignNominalDateAssignment_swigregister(StepAP214_AutoDesignNominalDateAssignment)

class StepAP214_AutoDesignOrganizationAssignment(OCC.Core.StepBasic.StepBasic_OrganizationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignorganizationassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignOrganizationAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignOrganizationAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedOrganization: StepBasic_Organization
        aRole: StepBasic_OrganizationRole
        aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignOrganizationAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignGeneralOrgItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignGeneralOrgItem>

        """
        return _StepAP214.StepAP214_AutoDesignOrganizationAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignGeneralOrgItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignGeneralOrgItem

        """
        return _StepAP214.StepAP214_AutoDesignOrganizationAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignOrganizationAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignOrganizationAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignOrganizationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignOrganizationAssignment

# Register StepAP214_AutoDesignOrganizationAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignOrganizationAssignment_swigregister(StepAP214_AutoDesignOrganizationAssignment)

class StepAP214_AutoDesignPersonAndOrganizationAssignment(OCC.Core.StepBasic.StepBasic_PersonAndOrganizationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignpersonandorganizationassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignPersonAndOrganizationAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignPersonAndOrganizationAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedPersonAndOrganization: StepBasic_PersonAndOrganization
        aRole: StepBasic_PersonAndOrganizationRole
        aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignPersonAndOrganizationAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignGeneralOrgItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignGeneralOrgItem>

        """
        return _StepAP214.StepAP214_AutoDesignPersonAndOrganizationAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignGeneralOrgItem":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignGeneralOrgItem

        """
        return _StepAP214.StepAP214_AutoDesignPersonAndOrganizationAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignPersonAndOrganizationAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignGeneralOrgItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignPersonAndOrganizationAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignPersonAndOrganizationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignPersonAndOrganizationAssignment

# Register StepAP214_AutoDesignPersonAndOrganizationAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignPersonAndOrganizationAssignment_swigregister(StepAP214_AutoDesignPersonAndOrganizationAssignment)

class StepAP214_AutoDesignPresentedItem(OCC.Core.StepVisual.StepVisual_PresentedItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignpresenteditem.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignPresentedItem_swiginit(self, _StepAP214.new_StepAP214_AutoDesignPresentedItem(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignPresentedItemSelect

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItem_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP214_HArray1OfAutoDesignPresentedItemSelect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepAP214_HArray1OfAutoDesignPresentedItemSelect>

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItem_Items(self, *args)

    def ItemsValue(self, *args) -> "StepAP214_AutoDesignPresentedItemSelect":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        StepAP214_AutoDesignPresentedItemSelect

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItem_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItem_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepAP214_HArray1OfAutoDesignPresentedItemSelect

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItem_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignPresentedItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignPresentedItem

# Register StepAP214_AutoDesignPresentedItem in _StepAP214:
_StepAP214.StepAP214_AutoDesignPresentedItem_swigregister(StepAP214_AutoDesignPresentedItem)

class StepAP214_AutoDesignPresentedItemSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignpresenteditemselect selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignPresentedItemSelect_swiginit(self, _StepAP214.new_StepAP214_AutoDesignPresentedItemSelect(*args))

    def DocumentRelationship(self, *args) -> "opencascade::handle< StepBasic_DocumentRelationship >":
        r"""
        Returns value as a documentrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_DocumentRelationship>

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItemSelect_DocumentRelationship(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as a productdefinition (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItemSelect_ProductDefinition(self, *args)

    def ProductDefinitionRelationship(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
        r"""
        Returns value as a productdefinitionrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionRelationship>

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItemSelect_ProductDefinitionRelationship(self, *args)

    def ProductDefinitionShape(self, *args) -> "opencascade::handle< StepRepr_ProductDefinitionShape >":
        r"""
        Returns value as a productdefinitionshape (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ProductDefinitionShape>

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItemSelect_ProductDefinitionShape(self, *args)

    def RepresentationRelationship(self, *args) -> "opencascade::handle< StepRepr_RepresentationRelationship >":
        r"""
        Returns value as a representationrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationRelationship>

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItemSelect_RepresentationRelationship(self, *args)

    def ShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns value as a shapeaspect (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepAP214.StepAP214_AutoDesignPresentedItemSelect_ShapeAspect(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignPresentedItemSelect

# Register StepAP214_AutoDesignPresentedItemSelect in _StepAP214:
_StepAP214.StepAP214_AutoDesignPresentedItemSelect_swigregister(StepAP214_AutoDesignPresentedItemSelect)

class StepAP214_AutoDesignReferencingItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignreferencingitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignReferencingItem_swiginit(self, _StepAP214.new_StepAP214_AutoDesignReferencingItem(*args))

    def Approval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_Approval(self, *args)

    def DocumentRelationship(self, *args) -> "opencascade::handle< StepBasic_DocumentRelationship >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_DocumentRelationship>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_DocumentRelationship(self, *args)

    def ExternallyDefinedRepresentation(self, *args) -> "opencascade::handle< StepRepr_ExternallyDefinedRepresentation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_ExternallyDefinedRepresentation>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_ExternallyDefinedRepresentation(self, *args)

    def MappedItem(self, *args) -> "opencascade::handle< StepRepr_MappedItem >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_MappedItem>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_MappedItem(self, *args)

    def MaterialDesignation(self, *args) -> "opencascade::handle< StepRepr_MaterialDesignation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_MaterialDesignation>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_MaterialDesignation(self, *args)

    def PresentationArea(self, *args) -> "opencascade::handle< StepVisual_PresentationArea >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PresentationArea>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_PresentationArea(self, *args)

    def PresentationView(self, *args) -> "opencascade::handle< StepVisual_PresentationView >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepVisual_PresentationView>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_PresentationView(self, *args)

    def ProductCategory(self, *args) -> "opencascade::handle< StepBasic_ProductCategory >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductCategory>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_ProductCategory(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_ProductDefinition(self, *args)

    def ProductDefinitionRelationship(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionRelationship>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_ProductDefinitionRelationship(self, *args)

    def PropertyDefinition(self, *args) -> "opencascade::handle< StepRepr_PropertyDefinition >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_PropertyDefinition>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_PropertyDefinition(self, *args)

    def Representation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_Representation(self, *args)

    def RepresentationRelationship(self, *args) -> "opencascade::handle< StepRepr_RepresentationRelationship >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationRelationship>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_RepresentationRelationship(self, *args)

    def ShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepAP214.StepAP214_AutoDesignReferencingItem_ShapeAspect(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignReferencingItem

# Register StepAP214_AutoDesignReferencingItem in _StepAP214:
_StepAP214.StepAP214_AutoDesignReferencingItem_swigregister(StepAP214_AutoDesignReferencingItem)

class StepAP214_AutoDesignSecurityClassificationAssignment(OCC.Core.StepBasic.StepBasic_SecurityClassificationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a autodesignsecurityclassificationassignment.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignSecurityClassificationAssignment_swiginit(self, _StepAP214.new_StepAP214_AutoDesignSecurityClassificationAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aAssignedSecurityClassification: StepBasic_SecurityClassification
        aItems: StepBasic_HArray1OfApproval

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignSecurityClassificationAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepBasic_HArray1OfApproval >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_HArray1OfApproval>

        """
        return _StepAP214.StepAP214_AutoDesignSecurityClassificationAssignment_Items(self, *args)

    def ItemsValue(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        No available documentation.

        Parameters
        ----------
        num: int

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepAP214.StepAP214_AutoDesignSecurityClassificationAssignment_ItemsValue(self, *args)

    def NbItems(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _StepAP214.StepAP214_AutoDesignSecurityClassificationAssignment_NbItems(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aItems: StepBasic_HArray1OfApproval

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_AutoDesignSecurityClassificationAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_AutoDesignSecurityClassificationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignSecurityClassificationAssignment

# Register StepAP214_AutoDesignSecurityClassificationAssignment in _StepAP214:
_StepAP214.StepAP214_AutoDesignSecurityClassificationAssignment_swigregister(StepAP214_AutoDesignSecurityClassificationAssignment)

class StepAP214_Class(OCC.Core.StepBasic.StepBasic_Group):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_Class_swiginit(self, _StepAP214.new_StepAP214_Class(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_Class_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_Class

# Register StepAP214_Class in _StepAP214:
_StepAP214.StepAP214_Class_swigregister(StepAP214_Class)

class StepAP214_DocumentReferenceItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a documentreferenceitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_DocumentReferenceItem_swiginit(self, _StepAP214.new_StepAP214_DocumentReferenceItem(*args))

    def AppliedExternalIdentificationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedExternalIdentificationAssignment >":
        r"""
        Returns value as a appliedexternalidentificationassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedExternalIdentificationAssignment>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_AppliedExternalIdentificationAssignment(self, *args)

    def Approval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        Returns value as a approval (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_Approval(self, *args)

    def AssemblyComponentUsage(self, *args) -> "opencascade::handle< StepRepr_AssemblyComponentUsage >":
        r"""
        Returns value as a assemblycomponentusage (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_AssemblyComponentUsage>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_AssemblyComponentUsage(self, *args)

    def CharacterizedObject(self, *args) -> "opencascade::handle< StepBasic_CharacterizedObject >":
        r"""
        Returns value as a characterizedobject (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_CharacterizedObject>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_CharacterizedObject(self, *args)

    def DescriptiveRepresentationItem(self, *args) -> "opencascade::handle< StepRepr_DescriptiveRepresentationItem >":
        r"""
        Returns value as a (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_DescriptiveRepresentationItem>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_DescriptiveRepresentationItem(self, *args)

    def DimensionalSize(self, *args) -> "opencascade::handle< StepShape_DimensionalSize >":
        r"""
        Returns value as a dimensionalsize (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_DimensionalSize>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_DimensionalSize(self, *args)

    def ExternallyDefinedItem(self, *args) -> "opencascade::handle< StepBasic_ExternallyDefinedItem >":
        r"""
        Returns value as a externallydefineditem (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ExternallyDefinedItem>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_ExternallyDefinedItem(self, *args)

    def Group(self, *args) -> "opencascade::handle< StepBasic_Group >":
        r"""
        Returns value as a group (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Group>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_Group(self, *args)

    def GroupRelationship(self, *args) -> "opencascade::handle< StepBasic_GroupRelationship >":
        r"""
        Returns value as a grouprelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_GroupRelationship>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_GroupRelationship(self, *args)

    def MaterialDesignation(self, *args) -> "opencascade::handle< StepRepr_MaterialDesignation >":
        r"""
        Returns value as a materialdesignation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_MaterialDesignation>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_MaterialDesignation(self, *args)

    def MeasureRepresentationItem(self, *args) -> "opencascade::handle< StepRepr_MeasureRepresentationItem >":
        r"""
        Returns value as a measurerepresentationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_MeasureRepresentationItem>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_MeasureRepresentationItem(self, *args)

    def ProductCategory(self, *args) -> "opencascade::handle< StepBasic_ProductCategory >":
        r"""
        Returns value as a productcategory (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductCategory>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_ProductCategory(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as a productdefinition (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_ProductDefinition(self, *args)

    def ProductDefinitionContext(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionContext >":
        r"""
        Returns value as a productdefinitioncontext (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionContext>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_ProductDefinitionContext(self, *args)

    def ProductDefinitionRelationship(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
        r"""
        Returns value as aproductdefinitionrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionRelationship>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_ProductDefinitionRelationship(self, *args)

    def PropertyDefinition(self, *args) -> "opencascade::handle< StepRepr_PropertyDefinition >":
        r"""
        Returns value as a propertydefinition (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_PropertyDefinition>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_PropertyDefinition(self, *args)

    def Representation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        Returns value as a representation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_Representation(self, *args)

    def RepresentationItem(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        Returns value as a representationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_RepresentationItem(self, *args)

    def ShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns value as a shapeaspect (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_ShapeAspect(self, *args)

    def ShapeAspectRelationship(self, *args) -> "opencascade::handle< StepRepr_ShapeAspectRelationship >":
        r"""
        Returns value as a shapeaspectrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspectRelationship>

        """
        return _StepAP214.StepAP214_DocumentReferenceItem_ShapeAspectRelationship(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_DocumentReferenceItem

# Register StepAP214_DocumentReferenceItem in _StepAP214:
_StepAP214.StepAP214_DocumentReferenceItem_swigregister(StepAP214_DocumentReferenceItem)

class StepAP214_ExternalIdentificationItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_ExternalIdentificationItem_swiginit(self, _StepAP214.new_StepAP214_ExternalIdentificationItem(*args))

    def AppliedOrganizationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedOrganizationAssignment >":
        r"""
        Returns value as appliedorganizationassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedOrganizationAssignment>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_AppliedOrganizationAssignment(self, *args)

    def AppliedPersonAndOrganizationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedPersonAndOrganizationAssignment >":
        r"""
        Returns value as appliedpersonandorganizationassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedPersonAndOrganizationAssignment>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_AppliedPersonAndOrganizationAssignment(self, *args)

    def Approval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        Returns value as approval (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_Approval(self, *args)

    def ApprovalStatus(self, *args) -> "opencascade::handle< StepBasic_ApprovalStatus >":
        r"""
        Returns value as approvalstatus (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalStatus>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_ApprovalStatus(self, *args)

    def DateAndTimeAssignment(self, *args) -> "opencascade::handle< StepBasic_DateAndTimeAssignment >":
        r"""
        Returns value as dateandtimeassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_DateAndTimeAssignment>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_DateAndTimeAssignment(self, *args)

    def DateAssignment(self, *args) -> "opencascade::handle< StepBasic_DateAssignment >":
        r"""
        Returns value as dateassignment (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_DateAssignment>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_DateAssignment(self, *args)

    def DocumentFile(self, *args) -> "opencascade::handle< StepBasic_DocumentFile >":
        r"""
        Returns value as documentfile (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_DocumentFile>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_DocumentFile(self, *args)

    def ExternalSource(self, *args) -> "opencascade::handle< StepBasic_ExternalSource >":
        r"""
        Returns value as externalsource (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ExternalSource>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_ExternalSource(self, *args)

    def ExternallyDefinedClass(self, *args) -> "opencascade::handle< StepAP214_ExternallyDefinedClass >":
        r"""
        Returns value as externallydefinedclass (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_ExternallyDefinedClass>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_ExternallyDefinedClass(self, *args)

    def ExternallyDefinedGeneralProperty(self, *args) -> "opencascade::handle< StepAP214_ExternallyDefinedGeneralProperty >":
        r"""
        Returns value as externallydefinedgeneralproperty (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_ExternallyDefinedGeneralProperty>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_ExternallyDefinedGeneralProperty(self, *args)

    def OrganizationalAddress(self, *args) -> "opencascade::handle< StepBasic_OrganizationalAddress >":
        r"""
        Returns value as organizationaladdress (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_OrganizationalAddress>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_OrganizationalAddress(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as productdefinition (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_ProductDefinition(self, *args)

    def SecurityClassification(self, *args) -> "opencascade::handle< StepBasic_SecurityClassification >":
        r"""
        Returns value as securityclassification (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_SecurityClassification>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_SecurityClassification(self, *args)

    def TrimmedCurve(self, *args) -> "opencascade::handle< StepGeom_TrimmedCurve >":
        r"""
        Returns value as trimmedcurve (or null if another type).

        Returns
        -------
        opencascade::handle<StepGeom_TrimmedCurve>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_TrimmedCurve(self, *args)

    def VersionedActionRequest(self, *args) -> "opencascade::handle< StepBasic_VersionedActionRequest >":
        r"""
        Returns value as versionedactionrequest (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_VersionedActionRequest>

        """
        return _StepAP214.StepAP214_ExternalIdentificationItem_VersionedActionRequest(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_ExternalIdentificationItem

# Register StepAP214_ExternalIdentificationItem in _StepAP214:
_StepAP214.StepAP214_ExternalIdentificationItem_swigregister(StepAP214_ExternalIdentificationItem)

class StepAP214_ExternallyDefinedGeneralProperty(OCC.Core.StepBasic.StepBasic_GeneralProperty):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_ExternallyDefinedGeneralProperty_swiginit(self, _StepAP214.new_StepAP214_ExternallyDefinedGeneralProperty(*args))

    def ExternallyDefinedItem(self, *args) -> "opencascade::handle< StepBasic_ExternallyDefinedItem >":
        r"""
        Returns data for supertype externallydefineditem.

        Returns
        -------
        opencascade::handle<StepBasic_ExternallyDefinedItem>

        """
        return _StepAP214.StepAP214_ExternallyDefinedGeneralProperty_ExternallyDefinedItem(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aGeneralProperty_Id: TCollection_HAsciiString
        aGeneralProperty_Name: TCollection_HAsciiString
        hasGeneralProperty_Description: bool
        aGeneralProperty_Description: TCollection_HAsciiString
        aExternallyDefinedItem_ItemId: StepBasic_SourceItem
        aExternallyDefinedItem_Source: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_ExternallyDefinedGeneralProperty_Init(self, *args)

    def SetExternallyDefinedItem(self, *args) -> "void":
        r"""
        Set data for supertype externallydefineditem.

        Parameters
        ----------
        ExternallyDefinedItem: StepBasic_ExternallyDefinedItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_ExternallyDefinedGeneralProperty_SetExternallyDefinedItem(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_ExternallyDefinedGeneralProperty_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_ExternallyDefinedGeneralProperty

# Register StepAP214_ExternallyDefinedGeneralProperty in _StepAP214:
_StepAP214.StepAP214_ExternallyDefinedGeneralProperty_swigregister(StepAP214_ExternallyDefinedGeneralProperty)

class StepAP214_GroupItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a groupitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_GroupItem_swiginit(self, _StepAP214.new_StepAP214_GroupItem(*args))

    def GeometricRepresentationItem(self, *args) -> "opencascade::handle< StepGeom_GeometricRepresentationItem >":
        r"""
        Returns value as a geometricrepresentationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepGeom_GeometricRepresentationItem>

        """
        return _StepAP214.StepAP214_GroupItem_GeometricRepresentationItem(self, *args)

    def GroupRelationship(self, *args) -> "opencascade::handle< StepBasic_GroupRelationship >":
        r"""
        Returns value as a grouprelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_GroupRelationship>

        """
        return _StepAP214.StepAP214_GroupItem_GroupRelationship(self, *args)

    def MappedItem(self, *args) -> "opencascade::handle< StepRepr_MappedItem >":
        r"""
        Returns value as a mappeditem (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_MappedItem>

        """
        return _StepAP214.StepAP214_GroupItem_MappedItem(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as a productdefinition (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP214.StepAP214_GroupItem_ProductDefinition(self, *args)

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as a productdefinitionformation (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP214.StepAP214_GroupItem_ProductDefinitionFormation(self, *args)

    def PropertyDefinitionRepresentation(self, *args) -> "opencascade::handle< StepRepr_PropertyDefinitionRepresentation >":
        r"""
        Returns value as a propertydefinitionrepresentation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_PropertyDefinitionRepresentation>

        """
        return _StepAP214.StepAP214_GroupItem_PropertyDefinitionRepresentation(self, *args)

    def Representation(self, *args) -> "opencascade::handle< StepRepr_Representation >":
        r"""
        Returns value as a representation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_Representation>

        """
        return _StepAP214.StepAP214_GroupItem_Representation(self, *args)

    def RepresentationItem(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        Returns value as a representationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepAP214.StepAP214_GroupItem_RepresentationItem(self, *args)

    def RepresentationRelationshipWithTransformation(self, *args) -> "opencascade::handle< StepRepr_RepresentationRelationshipWithTransformation >":
        r"""
        Returns value as a representationrelationshipwithtransformation (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationRelationshipWithTransformation>

        """
        return _StepAP214.StepAP214_GroupItem_RepresentationRelationshipWithTransformation(self, *args)

    def ShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns value as a shapeaspect (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepAP214.StepAP214_GroupItem_ShapeAspect(self, *args)

    def ShapeAspectRelationship(self, *args) -> "opencascade::handle< StepRepr_ShapeAspectRelationship >":
        r"""
        Returns value as a shapeaspectrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspectRelationship>

        """
        return _StepAP214.StepAP214_GroupItem_ShapeAspectRelationship(self, *args)

    def ShapeRepresentationRelationship(self, *args) -> "opencascade::handle< StepRepr_ShapeRepresentationRelationship >":
        r"""
        Returns value as a shaperepresentationrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeRepresentationRelationship>

        """
        return _StepAP214.StepAP214_GroupItem_ShapeRepresentationRelationship(self, *args)

    def StyledItem(self, *args) -> "opencascade::handle< StepVisual_StyledItem >":
        r"""
        Returns value as a styleditem (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_StyledItem>

        """
        return _StepAP214.StepAP214_GroupItem_StyledItem(self, *args)

    def TopologicalRepresentationItem(self, *args) -> "opencascade::handle< StepShape_TopologicalRepresentationItem >":
        r"""
        Returns value as a topologicalrepresentationitem (null if another type).

        Returns
        -------
        opencascade::handle<StepShape_TopologicalRepresentationItem>

        """
        return _StepAP214.StepAP214_GroupItem_TopologicalRepresentationItem(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_GroupItem

# Register StepAP214_GroupItem in _StepAP214:
_StepAP214.StepAP214_GroupItem_swigregister(StepAP214_GroupItem)

class StepAP214_PresentedItemSelect(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a presenteditemselect selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_PresentedItemSelect_swiginit(self, _StepAP214.new_StepAP214_PresentedItemSelect(*args))

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as a productdefinition (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP214.StepAP214_PresentedItemSelect_ProductDefinition(self, *args)

    def ProductDefinitionRelationship(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionRelationship >":
        r"""
        Returns value as a productdefinitionrelationship (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionRelationship>

        """
        return _StepAP214.StepAP214_PresentedItemSelect_ProductDefinitionRelationship(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_PresentedItemSelect

# Register StepAP214_PresentedItemSelect in _StepAP214:
_StepAP214.StepAP214_PresentedItemSelect_swigregister(StepAP214_PresentedItemSelect)

class StepAP214_Protocol(OCC.Core.StepData.StepData_Protocol):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_Protocol_swiginit(self, _StepAP214.new_StepAP214_Protocol(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_Protocol_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_Protocol

# Register StepAP214_Protocol in _StepAP214:
_StepAP214.StepAP214_Protocol_swigregister(StepAP214_Protocol)

class StepAP214_RepItemGroup(OCC.Core.StepBasic.StepBasic_Group):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_RepItemGroup_swiginit(self, _StepAP214.new_StepAP214_RepItemGroup(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aGroup_Name: TCollection_HAsciiString
        hasGroup_Description: bool
        aGroup_Description: TCollection_HAsciiString
        aRepresentationItem_Name: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_RepItemGroup_Init(self, *args)

    def RepresentationItem(self, *args) -> "opencascade::handle< StepRepr_RepresentationItem >":
        r"""
        Returns data for supertype representationitem.

        Returns
        -------
        opencascade::handle<StepRepr_RepresentationItem>

        """
        return _StepAP214.StepAP214_RepItemGroup_RepresentationItem(self, *args)

    def SetRepresentationItem(self, *args) -> "void":
        r"""
        Set data for supertype representationitem.

        Parameters
        ----------
        RepresentationItem: StepRepr_RepresentationItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_RepItemGroup_SetRepresentationItem(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_RepItemGroup_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_RepItemGroup

# Register StepAP214_RepItemGroup in _StepAP214:
_StepAP214.StepAP214_RepItemGroup_swigregister(StepAP214_RepItemGroup)

class StepAP214_AutoDesignOrganizationItem(StepAP214_AutoDesignGeneralOrgItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_AutoDesignOrganizationItem_swiginit(self, _StepAP214.new_StepAP214_AutoDesignOrganizationItem(*args))

    def Document(self, *args) -> "opencascade::handle< StepBasic_Document >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_Document>

        """
        return _StepAP214.StepAP214_AutoDesignOrganizationItem_Document(self, *args)

    def PhysicallyModeledProductDefinition(self, *args) -> "opencascade::handle< StepBasic_PhysicallyModeledProductDefinition >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<StepBasic_PhysicallyModeledProductDefinition>

        """
        return _StepAP214.StepAP214_AutoDesignOrganizationItem_PhysicallyModeledProductDefinition(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_AutoDesignOrganizationItem

# Register StepAP214_AutoDesignOrganizationItem in _StepAP214:
_StepAP214.StepAP214_AutoDesignOrganizationItem_swigregister(StepAP214_AutoDesignOrganizationItem)

class StepAP214_DateAndTimeItem(StepAP214_ApprovalItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a dateandtimeitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_DateAndTimeItem_swiginit(self, _StepAP214.new_StepAP214_DateAndTimeItem(*args))

    def AppliedOrganizationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedOrganizationAssignment >":
        r"""
        Returns value as a appliedorganizationassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedOrganizationAssignment>

        """
        return _StepAP214.StepAP214_DateAndTimeItem_AppliedOrganizationAssignment(self, *args)

    def AppliedPersonAndOrganizationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedPersonAndOrganizationAssignment >":
        r"""
        Returns value as a applieddateandpersonassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedPersonAndOrganizationAssignment>

        """
        return _StepAP214.StepAP214_DateAndTimeItem_AppliedPersonAndOrganizationAssignment(self, *args)

    def ApprovalPersonOrganization(self, *args) -> "opencascade::handle< StepBasic_ApprovalPersonOrganization >":
        r"""
        Returns value as a approvalpersonorganization (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalPersonOrganization>

        """
        return _StepAP214.StepAP214_DateAndTimeItem_ApprovalPersonOrganization(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_DateAndTimeItem

# Register StepAP214_DateAndTimeItem in _StepAP214:
_StepAP214.StepAP214_DateAndTimeItem_swigregister(StepAP214_DateAndTimeItem)

class StepAP214_DateItem(StepAP214_ApprovalItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a dateitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_DateItem_swiginit(self, _StepAP214.new_StepAP214_DateItem(*args))

    def AppliedOrganizationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedOrganizationAssignment >":
        r"""
        Returns value as a appliedorganizationassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedOrganizationAssignment>

        """
        return _StepAP214.StepAP214_DateItem_AppliedOrganizationAssignment(self, *args)

    def AppliedPersonAndOrganizationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedPersonAndOrganizationAssignment >":
        r"""
        Returns value as a applieddateandpersonassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedPersonAndOrganizationAssignment>

        """
        return _StepAP214.StepAP214_DateItem_AppliedPersonAndOrganizationAssignment(self, *args)

    def AppliedSecurityClassificationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedSecurityClassificationAssignment >":
        r"""
        Returns value as a appliedsecurityclassificationassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedSecurityClassificationAssignment>

        """
        return _StepAP214.StepAP214_DateItem_AppliedSecurityClassificationAssignment(self, *args)

    def ApprovalPersonOrganization(self, *args) -> "opencascade::handle< StepBasic_ApprovalPersonOrganization >":
        r"""
        Returns value as a approvalpersonorganization (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalPersonOrganization>

        """
        return _StepAP214.StepAP214_DateItem_ApprovalPersonOrganization(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_DateItem

# Register StepAP214_DateItem in _StepAP214:
_StepAP214.StepAP214_DateItem_swigregister(StepAP214_DateItem)

class StepAP214_ExternallyDefinedClass(StepAP214_Class):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_ExternallyDefinedClass_swiginit(self, _StepAP214.new_StepAP214_ExternallyDefinedClass(*args))

    def ExternallyDefinedItem(self, *args) -> "opencascade::handle< StepBasic_ExternallyDefinedItem >":
        r"""
        Returns data for supertype externallydefineditem.

        Returns
        -------
        opencascade::handle<StepBasic_ExternallyDefinedItem>

        """
        return _StepAP214.StepAP214_ExternallyDefinedClass_ExternallyDefinedItem(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aGroup_Name: TCollection_HAsciiString
        hasGroup_Description: bool
        aGroup_Description: TCollection_HAsciiString
        aExternallyDefinedItem_ItemId: StepBasic_SourceItem
        aExternallyDefinedItem_Source: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_ExternallyDefinedClass_Init(self, *args)

    def SetExternallyDefinedItem(self, *args) -> "void":
        r"""
        Set data for supertype externallydefineditem.

        Parameters
        ----------
        ExternallyDefinedItem: StepBasic_ExternallyDefinedItem

        Returns
        -------
        None

        """
        return _StepAP214.StepAP214_ExternallyDefinedClass_SetExternallyDefinedItem(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_ExternallyDefinedClass_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_ExternallyDefinedClass

# Register StepAP214_ExternallyDefinedClass in _StepAP214:
_StepAP214.StepAP214_ExternallyDefinedClass_swigregister(StepAP214_ExternallyDefinedClass)

class StepAP214_OrganizationItem(StepAP214_ApprovalItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a organizationitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_OrganizationItem_swiginit(self, _StepAP214.new_StepAP214_OrganizationItem(*args))

    def AppliedOrganizationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedOrganizationAssignment >":
        r"""
        Returns value as a appliedorganizationassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedOrganizationAssignment>

        """
        return _StepAP214.StepAP214_OrganizationItem_AppliedOrganizationAssignment(self, *args)

    def AppliedSecurityClassificationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedSecurityClassificationAssignment >":
        r"""
        Returns value as a appliedsecurityclassificationassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedSecurityClassificationAssignment>

        """
        return _StepAP214.StepAP214_OrganizationItem_AppliedSecurityClassificationAssignment(self, *args)

    def Approval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        Returns value as a approval (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepAP214.StepAP214_OrganizationItem_Approval(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_OrganizationItem

# Register StepAP214_OrganizationItem in _StepAP214:
_StepAP214.StepAP214_OrganizationItem_swigregister(StepAP214_OrganizationItem)

class StepAP214_PersonAndOrganizationItem(StepAP214_ApprovalItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a personandorganizationitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_PersonAndOrganizationItem_swiginit(self, _StepAP214.new_StepAP214_PersonAndOrganizationItem(*args))

    def AppliedOrganizationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedOrganizationAssignment >":
        r"""
        Returns value as a appliedorganizationassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedOrganizationAssignment>

        """
        return _StepAP214.StepAP214_PersonAndOrganizationItem_AppliedOrganizationAssignment(self, *args)

    def AppliedSecurityClassificationAssignment(self, *args) -> "opencascade::handle< StepAP214_AppliedSecurityClassificationAssignment >":
        r"""
        Returns value as a appliedsecurityclassificationassignment (null if another type).

        Returns
        -------
        opencascade::handle<StepAP214_AppliedSecurityClassificationAssignment>

        """
        return _StepAP214.StepAP214_PersonAndOrganizationItem_AppliedSecurityClassificationAssignment(self, *args)

    def Approval(self, *args) -> "opencascade::handle< StepBasic_Approval >":
        r"""
        Returns value as a approval (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Approval>

        """
        return _StepAP214.StepAP214_PersonAndOrganizationItem_Approval(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_PersonAndOrganizationItem

# Register StepAP214_PersonAndOrganizationItem in _StepAP214:
_StepAP214.StepAP214_PersonAndOrganizationItem_swigregister(StepAP214_PersonAndOrganizationItem)

class StepAP214_SecurityClassificationItem(StepAP214_ApprovalItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Returns a securityclassificationitem selecttype.

        Returns
        -------
        None

        """
        _StepAP214.StepAP214_SecurityClassificationItem_swiginit(self, _StepAP214.new_StepAP214_SecurityClassificationItem(*args))

    def Action(self, *args) -> "opencascade::handle< StepBasic_Action >":
        r"""
        Returns value as a action (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Action>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_Action(self, *args)

    def AssemblyComponentUsage(self, *args) -> "opencascade::handle< StepRepr_AssemblyComponentUsage >":
        r"""
        Returns value as a assemblycomponentusage (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_AssemblyComponentUsage>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_AssemblyComponentUsage(self, *args)

    def ConfigurationDesign(self, *args) -> "opencascade::handle< StepRepr_ConfigurationDesign >":
        r"""
        Returns value as a configurationdesign (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ConfigurationDesign>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_ConfigurationDesign(self, *args)

    def ConfigurationEffectivity(self, *args) -> "opencascade::handle< StepRepr_ConfigurationEffectivity >":
        r"""
        Returns value as a configurationeffectivity (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ConfigurationEffectivity>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_ConfigurationEffectivity(self, *args)

    def DraughtingModel(self, *args) -> "opencascade::handle< StepVisual_DraughtingModel >":
        r"""
        Returns value as a draughtingmodel (null if another type).

        Returns
        -------
        opencascade::handle<StepVisual_DraughtingModel>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_DraughtingModel(self, *args)

    def GeneralProperty(self, *args) -> "opencascade::handle< StepBasic_GeneralProperty >":
        r"""
        Returns value as a generalproperty (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_GeneralProperty>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_GeneralProperty(self, *args)

    def MakeFromUsageOption(self, *args) -> "opencascade::handle< StepRepr_MakeFromUsageOption >":
        r"""
        Returns value as a makefromusageoption (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_MakeFromUsageOption>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_MakeFromUsageOption(self, *args)

    def ProductConcept(self, *args) -> "opencascade::handle< StepRepr_ProductConcept >":
        r"""
        Returns value as a productconcept (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ProductConcept>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_ProductConcept(self, *args)

    def ProductDefinitionUsage(self, *args) -> "opencascade::handle< StepRepr_ProductDefinitionUsage >":
        r"""
        Returns value as a productdefinitionusage (null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ProductDefinitionUsage>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_ProductDefinitionUsage(self, *args)

    def VersionedActionRequest(self, *args) -> "opencascade::handle< StepBasic_VersionedActionRequest >":
        r"""
        Returns value as a versionedactionrequest (null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_VersionedActionRequest>

        """
        return _StepAP214.StepAP214_SecurityClassificationItem_VersionedActionRequest(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP214.delete_StepAP214_SecurityClassificationItem

# Register StepAP214_SecurityClassificationItem in _StepAP214:
_StepAP214.StepAP214_SecurityClassificationItem_swigregister(StepAP214_SecurityClassificationItem)

class StepAP214_HArray1OfDateItem(StepAP214_Array1OfDateItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfDateItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfDateItem(*args))

    def Array1(self) -> "StepAP214_Array1OfDateItem const &":
        return _StepAP214.StepAP214_HArray1OfDateItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfDateItem &":
        return _StepAP214.StepAP214_HArray1OfDateItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfDateItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfDateItem

# Register StepAP214_HArray1OfDateItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfDateItem_swigregister(StepAP214_HArray1OfDateItem)

class StepAP214_HArray1OfSecurityClassificationItem(StepAP214_Array1OfSecurityClassificationItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfSecurityClassificationItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfSecurityClassificationItem(*args))

    def Array1(self) -> "StepAP214_Array1OfSecurityClassificationItem const &":
        return _StepAP214.StepAP214_HArray1OfSecurityClassificationItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfSecurityClassificationItem &":
        return _StepAP214.StepAP214_HArray1OfSecurityClassificationItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfSecurityClassificationItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfSecurityClassificationItem

# Register StepAP214_HArray1OfSecurityClassificationItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfSecurityClassificationItem_swigregister(StepAP214_HArray1OfSecurityClassificationItem)

class StepAP214_HArray1OfExternalIdentificationItem(StepAP214_Array1OfExternalIdentificationItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfExternalIdentificationItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfExternalIdentificationItem(*args))

    def Array1(self) -> "StepAP214_Array1OfExternalIdentificationItem const &":
        return _StepAP214.StepAP214_HArray1OfExternalIdentificationItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfExternalIdentificationItem &":
        return _StepAP214.StepAP214_HArray1OfExternalIdentificationItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfExternalIdentificationItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfExternalIdentificationItem

# Register StepAP214_HArray1OfExternalIdentificationItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfExternalIdentificationItem_swigregister(StepAP214_HArray1OfExternalIdentificationItem)

class StepAP214_HArray1OfAutoDesignDatedItem(StepAP214_Array1OfAutoDesignDatedItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfAutoDesignDatedItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfAutoDesignDatedItem(*args))

    def Array1(self) -> "StepAP214_Array1OfAutoDesignDatedItem const &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignDatedItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfAutoDesignDatedItem &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignDatedItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfAutoDesignDatedItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfAutoDesignDatedItem

# Register StepAP214_HArray1OfAutoDesignDatedItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfAutoDesignDatedItem_swigregister(StepAP214_HArray1OfAutoDesignDatedItem)

class StepAP214_HArray1OfPersonAndOrganizationItem(StepAP214_Array1OfPersonAndOrganizationItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfPersonAndOrganizationItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfPersonAndOrganizationItem(*args))

    def Array1(self) -> "StepAP214_Array1OfPersonAndOrganizationItem const &":
        return _StepAP214.StepAP214_HArray1OfPersonAndOrganizationItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfPersonAndOrganizationItem &":
        return _StepAP214.StepAP214_HArray1OfPersonAndOrganizationItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfPersonAndOrganizationItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfPersonAndOrganizationItem

# Register StepAP214_HArray1OfPersonAndOrganizationItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfPersonAndOrganizationItem_swigregister(StepAP214_HArray1OfPersonAndOrganizationItem)

class StepAP214_HArray1OfAutoDesignDateAndPersonItem(StepAP214_Array1OfAutoDesignDateAndPersonItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfAutoDesignDateAndPersonItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfAutoDesignDateAndPersonItem(*args))

    def Array1(self) -> "StepAP214_Array1OfAutoDesignDateAndPersonItem const &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignDateAndPersonItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfAutoDesignDateAndPersonItem &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignDateAndPersonItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfAutoDesignDateAndPersonItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfAutoDesignDateAndPersonItem

# Register StepAP214_HArray1OfAutoDesignDateAndPersonItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfAutoDesignDateAndPersonItem_swigregister(StepAP214_HArray1OfAutoDesignDateAndPersonItem)

class StepAP214_HArray1OfAutoDesignGroupedItem(StepAP214_Array1OfAutoDesignGroupedItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfAutoDesignGroupedItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfAutoDesignGroupedItem(*args))

    def Array1(self) -> "StepAP214_Array1OfAutoDesignGroupedItem const &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignGroupedItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfAutoDesignGroupedItem &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignGroupedItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfAutoDesignGroupedItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfAutoDesignGroupedItem

# Register StepAP214_HArray1OfAutoDesignGroupedItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfAutoDesignGroupedItem_swigregister(StepAP214_HArray1OfAutoDesignGroupedItem)

class StepAP214_HArray1OfPresentedItemSelect(StepAP214_Array1OfPresentedItemSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfPresentedItemSelect_swiginit(self, _StepAP214.new_StepAP214_HArray1OfPresentedItemSelect(*args))

    def Array1(self) -> "StepAP214_Array1OfPresentedItemSelect const &":
        return _StepAP214.StepAP214_HArray1OfPresentedItemSelect_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfPresentedItemSelect &":
        return _StepAP214.StepAP214_HArray1OfPresentedItemSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfPresentedItemSelect_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfPresentedItemSelect

# Register StepAP214_HArray1OfPresentedItemSelect in _StepAP214:
_StepAP214.StepAP214_HArray1OfPresentedItemSelect_swigregister(StepAP214_HArray1OfPresentedItemSelect)

class StepAP214_HArray1OfAutoDesignGeneralOrgItem(StepAP214_Array1OfAutoDesignGeneralOrgItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfAutoDesignGeneralOrgItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfAutoDesignGeneralOrgItem(*args))

    def Array1(self) -> "StepAP214_Array1OfAutoDesignGeneralOrgItem const &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignGeneralOrgItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfAutoDesignGeneralOrgItem &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignGeneralOrgItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfAutoDesignGeneralOrgItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfAutoDesignGeneralOrgItem

# Register StepAP214_HArray1OfAutoDesignGeneralOrgItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfAutoDesignGeneralOrgItem_swigregister(StepAP214_HArray1OfAutoDesignGeneralOrgItem)

class StepAP214_HArray1OfAutoDesignDateAndTimeItem(StepAP214_Array1OfAutoDesignDateAndTimeItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfAutoDesignDateAndTimeItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfAutoDesignDateAndTimeItem(*args))

    def Array1(self) -> "StepAP214_Array1OfAutoDesignDateAndTimeItem const &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignDateAndTimeItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfAutoDesignDateAndTimeItem &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignDateAndTimeItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfAutoDesignDateAndTimeItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfAutoDesignDateAndTimeItem

# Register StepAP214_HArray1OfAutoDesignDateAndTimeItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfAutoDesignDateAndTimeItem_swigregister(StepAP214_HArray1OfAutoDesignDateAndTimeItem)

class StepAP214_HArray1OfAutoDesignPresentedItemSelect(StepAP214_Array1OfAutoDesignPresentedItemSelect, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfAutoDesignPresentedItemSelect_swiginit(self, _StepAP214.new_StepAP214_HArray1OfAutoDesignPresentedItemSelect(*args))

    def Array1(self) -> "StepAP214_Array1OfAutoDesignPresentedItemSelect const &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignPresentedItemSelect_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfAutoDesignPresentedItemSelect &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignPresentedItemSelect_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfAutoDesignPresentedItemSelect_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfAutoDesignPresentedItemSelect

# Register StepAP214_HArray1OfAutoDesignPresentedItemSelect in _StepAP214:
_StepAP214.StepAP214_HArray1OfAutoDesignPresentedItemSelect_swigregister(StepAP214_HArray1OfAutoDesignPresentedItemSelect)

class StepAP214_HArray1OfAutoDesignReferencingItem(StepAP214_Array1OfAutoDesignReferencingItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfAutoDesignReferencingItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfAutoDesignReferencingItem(*args))

    def Array1(self) -> "StepAP214_Array1OfAutoDesignReferencingItem const &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignReferencingItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfAutoDesignReferencingItem &":
        return _StepAP214.StepAP214_HArray1OfAutoDesignReferencingItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfAutoDesignReferencingItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfAutoDesignReferencingItem

# Register StepAP214_HArray1OfAutoDesignReferencingItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfAutoDesignReferencingItem_swigregister(StepAP214_HArray1OfAutoDesignReferencingItem)

class StepAP214_HArray1OfDocumentReferenceItem(StepAP214_Array1OfDocumentReferenceItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfDocumentReferenceItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfDocumentReferenceItem(*args))

    def Array1(self) -> "StepAP214_Array1OfDocumentReferenceItem const &":
        return _StepAP214.StepAP214_HArray1OfDocumentReferenceItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfDocumentReferenceItem &":
        return _StepAP214.StepAP214_HArray1OfDocumentReferenceItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfDocumentReferenceItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfDocumentReferenceItem

# Register StepAP214_HArray1OfDocumentReferenceItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfDocumentReferenceItem_swigregister(StepAP214_HArray1OfDocumentReferenceItem)

class StepAP214_HArray1OfOrganizationItem(StepAP214_Array1OfOrganizationItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfOrganizationItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfOrganizationItem(*args))

    def Array1(self) -> "StepAP214_Array1OfOrganizationItem const &":
        return _StepAP214.StepAP214_HArray1OfOrganizationItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfOrganizationItem &":
        return _StepAP214.StepAP214_HArray1OfOrganizationItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfOrganizationItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfOrganizationItem

# Register StepAP214_HArray1OfOrganizationItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfOrganizationItem_swigregister(StepAP214_HArray1OfOrganizationItem)

class StepAP214_HArray1OfApprovalItem(StepAP214_Array1OfApprovalItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfApprovalItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfApprovalItem(*args))

    def Array1(self) -> "StepAP214_Array1OfApprovalItem const &":
        return _StepAP214.StepAP214_HArray1OfApprovalItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfApprovalItem &":
        return _StepAP214.StepAP214_HArray1OfApprovalItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfApprovalItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfApprovalItem

# Register StepAP214_HArray1OfApprovalItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfApprovalItem_swigregister(StepAP214_HArray1OfApprovalItem)

class StepAP214_HArray1OfGroupItem(StepAP214_Array1OfGroupItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfGroupItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfGroupItem(*args))

    def Array1(self) -> "StepAP214_Array1OfGroupItem const &":
        return _StepAP214.StepAP214_HArray1OfGroupItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfGroupItem &":
        return _StepAP214.StepAP214_HArray1OfGroupItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfGroupItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfGroupItem

# Register StepAP214_HArray1OfGroupItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfGroupItem_swigregister(StepAP214_HArray1OfGroupItem)

class StepAP214_HArray1OfDateAndTimeItem(StepAP214_Array1OfDateAndTimeItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP214.StepAP214_HArray1OfDateAndTimeItem_swiginit(self, _StepAP214.new_StepAP214_HArray1OfDateAndTimeItem(*args))

    def Array1(self) -> "StepAP214_Array1OfDateAndTimeItem const &":
        return _StepAP214.StepAP214_HArray1OfDateAndTimeItem_Array1(self)

    def ChangeArray1(self) -> "StepAP214_Array1OfDateAndTimeItem &":
        return _StepAP214.StepAP214_HArray1OfDateAndTimeItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP214_HArray1OfDateAndTimeItem_DownCast(t)

    __swig_destroy__ = _StepAP214.delete_StepAP214_HArray1OfDateAndTimeItem

# Register StepAP214_HArray1OfDateAndTimeItem in _StepAP214:
_StepAP214.StepAP214_HArray1OfDateAndTimeItem_swigregister(StepAP214_HArray1OfDateAndTimeItem)





